@@ -22,7 +22,7 @@
 /* ************************************************************************** */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -31,7 +31,7 @@
 /*START_INCLUDE*/
 #include "categories_onglet.h"
 #include "dialog.h"
-#include "fenetre_principale.h"
+#include "grisbi_app.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_data_category.h"
@@ -39,7 +39,6 @@
 #include "gsb_file.h"
 #include "gsb_file_others.h"
 #include "gsb_transactions_list.h"
-#include "main.h"
 #include "meta_categories.h"
 #include "metatree.h"
 #include "mouse.h"
@@ -48,7 +47,7 @@
 #include "transaction_list.h"
 #include "utils.h"
 #include "utils_buttons.h"
-#include "utils_file_selection.h"
+#include "utils_files.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -79,7 +78,7 @@ static GtkWidget *arbre_categ = NULL;
 static gboolean sortie_edit_category = FALSE;
 
 /* structure pour la sauvegarde de la position */
-struct metatree_hold_position *category_hold_position;
+struct MetatreeHoldPosition *category_hold_position;
 
 
 /*START_EXTERN*/
@@ -95,12 +94,13 @@ struct metatree_hold_position *category_hold_position;
  * */
 void categories_init_variables_list ( void )
 {
-    categ_tree_model = NULL;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+    categ_tree_model = NULL;
     category_toolbar = NULL;
     arbre_categ = NULL;
-    etat.no_devise_totaux_categ = 1;
-
+    w_etat->no_devise_totaux_categ = 1;
     sortie_edit_category = FALSE;
 }
 
@@ -112,9 +112,10 @@ void categories_init_variables_list ( void )
  */
 GtkWidget *categories_create_list ( void )
 {
+    GtkWidget *scroll_window, *vbox;
+    GtkWidget *frame;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
-    GtkWidget *scroll_window, *vbox;
     GtkTreeDragDestIface * dst_iface;
     GtkTreeDragSourceIface * src_iface;
     static GtkTargetEntry row_targets[] = {
@@ -122,13 +123,20 @@ GtkWidget *categories_create_list ( void )
     };
     MetatreeInterface *category_interface;
 
+    /* We create the main vbox */
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+
+    /* frame pour la barre d'outils */
+    frame = gtk_frame_new ( NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), frame, FALSE, FALSE, 0 );
+
     category_interface = category_get_metatree_interface ( );
 
     /* We create the gtktreeview and model early so that they can be referenced. */
     arbre_categ = gtk_tree_view_new();
 
     /* set the color of selected row */
-    utils_set_tree_view_selection_and_text_color ( arbre_categ );
+	gtk_widget_set_name (arbre_categ, "tree_view");
 
     /* Create model */
     categ_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS, META_TREE_COLUMN_TYPES );
@@ -137,17 +145,11 @@ GtkWidget *categories_create_list ( void )
     gtk_tree_sortable_set_sort_func ( GTK_TREE_SORTABLE(categ_tree_model),
 				      META_TREE_TEXT_COLUMN, metatree_sort_column,
 				      NULL, NULL );
-    g_object_set_data ( G_OBJECT (categ_tree_model), "metatree-interface",
-			category_interface );
+    g_object_set_data ( G_OBJECT (categ_tree_model), "metatree-interface", category_interface );
 
-    /* We create the main vbox */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_widget_show ( vbox );
-
-    /* on y ajoute la barre d'outils */
-    category_toolbar = gtk_handle_box_new ();
-    gtk_widget_show ( category_toolbar );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), category_toolbar, FALSE, FALSE, 0 );
+    /* on y ajoute la barre d'outils après la création du model */
+    category_toolbar = creation_barre_outils_categ ();
+    gtk_container_add ( GTK_CONTAINER ( frame ), category_toolbar );
 
     /* création de l'arbre principal */
     scroll_window = gtk_scrolled_window_new ( NULL, NULL );
@@ -159,7 +161,6 @@ GtkWidget *categories_create_list ( void )
     gtk_widget_show ( scroll_window );
 
     /* Create container + TreeView */
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (arbre_categ), TRUE);
     gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(arbre_categ),
 					   GDK_BUTTON1_MASK, row_targets, 1,
 					   GDK_ACTION_MOVE | GDK_ACTION_COPY );
@@ -178,7 +179,7 @@ GtkWidget *categories_create_list ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Category"), cell,
 						       "text", META_TREE_TEXT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -188,18 +189,19 @@ GtkWidget *categories_create_list ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Account"), cell,
 						       "text", META_TREE_ACCOUNT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
 
     /* Make amount column */
     cell = gtk_cell_renderer_text_new ();
+	gtk_cell_renderer_set_padding (GTK_CELL_RENDERER (cell), MARGIN_BOX, 0);
     column = gtk_tree_view_column_new_with_attributes (_("Amount"), cell,
 						       "text", META_TREE_BALANCE_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
 						       "xalign", META_TREE_XALIGN_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_column_set_alignment ( column, 1.0 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( arbre_categ ),
@@ -252,7 +254,9 @@ GtkWidget *categories_create_list ( void )
                         categ_tree_model );
 
     /* création de la structure de sauvegarde de la position */
-    category_hold_position = g_malloc0 ( sizeof ( struct metatree_hold_position ) );
+    category_hold_position = g_malloc0 ( sizeof ( struct MetatreeHoldPosition ) );
+
+    gtk_widget_show_all ( vbox );
 
     return ( vbox );
 }
@@ -349,7 +353,7 @@ void categories_fill_list ( void )
             gtk_tree_path_free (ancestor );
         }
         /* on colorise les lignes du tree_view */
-        utils_set_tree_view_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
+        utils_set_tree_store_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( arbre_categ ) );
         gtk_tree_selection_select_path ( selection, category_hold_position -> path );
         gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( arbre_categ ),
@@ -361,11 +365,11 @@ void categories_fill_list ( void )
         gchar *title;
 
         /* on colorise les lignes du tree_view */
-        utils_set_tree_view_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
+        utils_set_tree_store_background_color ( arbre_categ, META_TREE_BACKGROUND_COLOR );
 	    title = g_strdup(_("Categories"));
-        gsb_gui_headings_update_title ( title );
+        grisbi_win_headings_update_title ( title );
         g_free ( title );
-        gsb_gui_headings_update_suffix ( "" );
+        grisbi_win_headings_update_suffix ( "" );
     }
 }
 
@@ -407,10 +411,10 @@ void categories_exporter_list ( void )
     gchar *tmp_last_directory;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export categories"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-save", GTK_RESPONSE_OK,
 					   NULL);
 
     gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ),  _("Categories.cgsb"));
@@ -426,8 +430,8 @@ void categories_exporter_list ( void )
         return;
     }
 
-    nom_categ = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
-    tmp_last_directory = file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
+    nom_categ = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( dialog ));
+    tmp_last_directory = utils_files_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
     gsb_file_update_last_path ( tmp_last_directory );
     g_free ( tmp_last_directory );
     gtk_widget_destroy ( GTK_WIDGET ( dialog ));
@@ -451,10 +455,10 @@ void categories_importer_list ( void )
     gchar *tmp_last_directory;
 
     dialog = gtk_file_chooser_dialog_new ( _("Import categories"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_OPEN,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-open", GTK_RESPONSE_OK,
 					   NULL);
 
     gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
@@ -479,8 +483,8 @@ void categories_importer_list ( void )
 	return;
     }
 
-    category_name = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
-    tmp_last_directory = file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
+    category_name = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( dialog ));
+    tmp_last_directory = utils_files_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
     gsb_file_update_last_path ( tmp_last_directory );
     g_free ( tmp_last_directory );
     gtk_widget_destroy ( GTK_WIDGET ( dialog ));
@@ -490,13 +494,13 @@ void categories_importer_list ( void )
     /* on permet de remplacer/fusionner la liste */
 
     dialog = dialogue_special_no_run ( GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-				       make_hint ( _("Merge imported categories with existing?"),
-						   ( last_transaction_number ?
-						     _("File already contains categories.  If you decide to continue, existing categories will be merged with imported ones.") :
-						     _("File does not contain categories.  "
-						       "If you decide to continue, existing categories will be merged with imported ones.  "
-						       "Once performed, there is no undo for this.\n"
-						       "You may also decide to replace existing categories with imported ones." ) ) ) );
+				       ( last_transaction_number ?
+				         _("File already contains categories.  If you decide to continue, existing categories will be merged with imported ones.") :
+				         _("File does not contain categories.  "
+				           "If you decide to continue, existing categories will be merged with imported ones.  "
+				           "Once performed, there is no undo for this.\n"
+				           "You may also decide to replace existing categories with imported ones." ) ),
+				       _("Merge imported categories with existing?") );
 
     if ( !last_transaction_number)
 	gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
@@ -504,8 +508,8 @@ void categories_importer_list ( void )
 				 NULL );
 
     gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
-			     GTK_STOCK_CANCEL, 0,
-			     GTK_STOCK_OK, 1,
+			     "gtk-cancel", 0,
+			     "gtk-ok", 1,
 			     NULL );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
@@ -513,21 +517,18 @@ void categories_importer_list ( void )
 
     switch ( resultat )
     {
-	case 2 :
-	    /* we want to replace the list */
+		case 1 :
+			gsb_file_others_load_category ( category_name );
+			return;
 
-	    if ( !last_transaction_number )
-		gsb_data_category_init_variables ();
+		case 2 :
+			/* we want to replace the list */
+			if ( !last_transaction_number )
+				gsb_data_category_init_variables ();
+			gsb_file_others_load_category ( category_name );
 
-        case 1 :
-	    if ( !gsb_file_others_load_category ( category_name ))
-	    {
-		return;
-	    }
-	    break;
-
-	default :
-	    return;
+		default :
+			return;
     }
 }
 
@@ -542,88 +543,91 @@ void categories_importer_list ( void )
  */
 GtkWidget *creation_barre_outils_categ ( void )
 {
-    GtkWidget *hbox, *button;
-    /* hbox */
-    hbox = gtk_hbox_new ( FALSE, 0 );
+    GtkWidget *toolbar;
+    GtkToolItem *item;
+
+    toolbar = gtk_toolbar_new ();
 
     /* New category button */
-    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                                                _("New\ncategory"),
-                                                "new-categ.png",
-                                                G_CALLBACK ( appui_sur_ajout_category ),
-                                                categ_tree_model );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Create a new category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (1) );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-new-categ-24.png", _("New\ncategory"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Create a new category") );
+    g_object_set_data ( G_OBJECT ( item ), "type", GINT_TO_POINTER (1) );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( appui_sur_ajout_category ),
+                        categ_tree_model );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* New sub category button */
-    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                                                _("New sub\ncategory"),
-                                                "new-sub-categ.png",
-                                                G_CALLBACK (appui_sur_ajout_category),
-                                                categ_tree_model );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "sub-division" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Create a new sub-category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (2) );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-new-sub-categ-24.png", _("New sub\ncategory"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "sub-division" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Create a new sub-category") );
+    g_object_set_data ( G_OBJECT ( item ), "type", GINT_TO_POINTER (2) );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( appui_sur_ajout_category ),
+                        categ_tree_model );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Import button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                            GTK_STOCK_OPEN,
-                                            _("Import"),
-                                            G_CALLBACK ( categories_importer_list ),
-                                            NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Import a Grisbi category file (.cgsb)"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-import-24.png", _("Import"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Import a Grisbi category file (.cgsb)") );
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( categories_importer_list ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                            GTK_STOCK_SAVE,
-                                            _("Export"),
-                                            G_CALLBACK ( categories_exporter_list ),
-                                            NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Export a Grisbi category file (.cgsb)"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-export-24.png", _("Export"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Export a Grisbi category file (.cgsb)") );
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( categories_exporter_list ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Delete button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                            GTK_STOCK_DELETE, _("Delete"),
-                                            G_CALLBACK ( supprimer_division ), arbre_categ );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Delete selected category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-delete-24.png", _("Delete"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Delete selected category") );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( supprimer_division ),
+                        arbre_categ );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Properties button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                            GTK_STOCK_EDIT, _("Edit"),
-                                            G_CALLBACK ( edit_category ), arbre_categ );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ), button, "selection" );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Edit selected category"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-edit-24.png", _("Edit"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( categ_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Edit selected category") );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( edit_category ),
+                        arbre_categ );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* View button */
-    button = gsb_automem_stock_button_menu_new ( conf.display_toolbar,
-                                                 GTK_STOCK_SELECT_COLOR,
-                                                 _("View"),
-                                                 G_CALLBACK ( popup_category_view_mode_menu ),
-                                                 NULL );
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
-                                  _("Change view mode"));
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-select-color-24.png", _("View"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Change view mode"));
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( popup_category_view_mode_menu ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
-    gtk_widget_show_all ( hbox );
+    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( categ_tree_model ), FALSE, "selection" );
 
-    metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( categ_tree_model ),
-                                            FALSE, "selection" );
-
-    return ( hbox );
+    return ( toolbar );
 }
 
 
@@ -632,19 +636,9 @@ GtkWidget *creation_barre_outils_categ ( void )
  *
  *
  */
-void categories_update_toolbar_list ( void )
+void gsb_gui_categories_toolbar_set_style ( gint toolbar_style )
 {
-    GList * list = NULL;
-
-    list = gtk_container_get_children ( GTK_CONTAINER ( category_toolbar ) );
-
-    if ( list )
-    {
-        gtk_container_remove ( GTK_CONTAINER ( category_toolbar ),
-                               GTK_WIDGET ( list -> data ) );
-        g_list_free ( list );
-    }
-    gtk_container_add ( GTK_CONTAINER ( category_toolbar ), creation_barre_outils_categ () );
+    gtk_toolbar_set_style ( GTK_TOOLBAR ( category_toolbar ), toolbar_style );
 }
 
 
@@ -663,19 +657,19 @@ gboolean popup_category_view_mode_menu ( GtkWidget *button )
     menu = gtk_menu_new ();
 
     /* Edit transaction */
-    menu_item = gtk_image_menu_item_new_with_label ( _("Category view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Category view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 0 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", arbre_categ );
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
 
-    menu_item = gtk_image_menu_item_new_with_label ( _("Subcategory view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Subcategory view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 1 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", arbre_categ );
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
 
-    menu_item = gtk_image_menu_item_new_with_label ( _("Complete view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Complete view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 2 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", arbre_categ );
@@ -683,9 +677,12 @@ gboolean popup_category_view_mode_menu ( GtkWidget *button )
 
     gtk_widget_show_all ( menu );
 
+#if GTK_CHECK_VERSION (3,22,0)
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
+#else
     gtk_menu_popup ( GTK_MENU(menu), NULL, button, set_popup_position, button, 1,
 		     gtk_get_current_event_time());
-
+#endif
     return FALSE;
 }
 
@@ -700,7 +697,7 @@ gboolean edit_category ( GtkTreeView *tree_view )
     GtkWidget * dialog, *paddingbox, *table, *label, *entry, *hbox, *radiogroup;
     gint category_number = -1, sub_category_number = -1;
     GtkTreeSelection * selection;
-    GtkTreeModel * model;
+    GtkTreeModel * model = NULL;
     GtkTreeIter iter;
     gchar * title;
     GtkTreeIter *div_iter;
@@ -730,33 +727,32 @@ gboolean edit_category ( GtkTreeView *tree_view )
 										       _("No category defined") ));
 
     dialog = gtk_dialog_new_with_buttons ( title,
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_DIALOG_MODAL,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
-					   GTK_STOCK_APPLY, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_NO,
+					   "gtk-apply", GTK_RESPONSE_OK,
 					   NULL );
 
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( dialog ), FALSE );
 
     /* Ugly dance to avoid side effects on dialog's vbox. */
-    hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_box_pack_start ( GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ), hbox, FALSE, FALSE, 0 );
     paddingbox = new_paddingbox_with_title ( hbox, TRUE, title );
     gtk_container_set_border_width ( GTK_CONTAINER(hbox), 6 );
     gtk_container_set_border_width ( GTK_CONTAINER(paddingbox), 6 );
     g_free ( title );
 
-    table = gtk_table_new ( 0, 2, FALSE );
+    table = gtk_grid_new ();
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
-    gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
 
     /* Name entry */
     label = gtk_label_new ( _("Name"));
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ( );
     if ( sub_category_number > 0 )
@@ -773,22 +769,20 @@ gboolean edit_category ( GtkTreeView *tree_view )
     }
 
     gtk_widget_set_size_request ( entry, 400, -1 );
-    gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), entry, 1, 0, 1, 1);
 
     if ( sub_category_number <= 0 )
     {
 	/* Description entry */
 	label = gtk_label_new ( _("Type"));
-	gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-	gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 1, 2,
-			   GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
+	utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	radiogroup = gsb_autofunc_radiobutton_new (  _("Credit"), _("Debit"),
 						     gsb_data_category_get_type (category_number),
 						     NULL, NULL,
 						     G_CALLBACK (gsb_data_category_set_type), category_number );
-	gtk_table_attach ( GTK_TABLE(table), radiogroup,
-			   1, 2, 1, 2, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), radiogroup, 1, 1, 1, 1);
     }
 
     gtk_widget_show_all ( dialog );
@@ -891,6 +885,7 @@ void appui_sur_ajout_category ( GtkTreeModel *model,
     gint type;
 
     type = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT (button), "type" ) );
+
     if ( type == 1 )
         metatree_new_division ( model );
     else
@@ -1020,10 +1015,10 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
     else if ( ev -> type == GDK_2BUTTON_PRESS )
     {
         GtkTreeSelection *selection;
-        GtkTreeModel *model;
+        GtkTreeModel *model = NULL;
         GtkTreeIter iter;
         GtkTreePath *path = NULL;
-        enum meta_tree_row_type type_division;
+        enum MetaTreeRowType type_division;
 
         type_division = metatree_get_row_type_from_tree_view ( tree_view );
         if ( type_division == META_TREE_TRANSACTION )
@@ -1032,6 +1027,8 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
         if ( selection && gtk_tree_selection_get_selected (selection, &model, &iter ) )
             path = gtk_tree_model_get_path  ( model, &iter);
+		else
+			return FALSE;
 
         if ( conf.metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
         {
@@ -1054,7 +1051,6 @@ gboolean category_list_button_press ( GtkWidget *tree_view,
         {
             if ( type_division == META_TREE_SUB_DIV || type_division == META_TREE_TRANS_S_S_DIV )
             {
-                    path = gtk_tree_model_get_path  ( model, &iter);
                     gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
 
                     gtk_tree_path_free ( path );
@@ -1082,7 +1078,7 @@ void category_list_popup_context_menu ( void )
     GtkWidget *menu;
     GtkWidget *menu_item;
     gchar *title;
-    enum meta_tree_row_type type_division;
+    enum MetaTreeRowType type_division;
 
     type_division = metatree_get_row_type_from_tree_view ( arbre_categ );
 
@@ -1095,10 +1091,7 @@ void category_list_popup_context_menu ( void )
     {
         title = g_strdup ( _("Transfers the identical transactions in another sub-category") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
-                        GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gsb-convert-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( metatree_transfer_identical_transactions ),
@@ -1117,10 +1110,7 @@ void category_list_popup_context_menu ( void )
         else
             title = g_strdup ( _("Edit selected sub-category") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                            gtk_image_new_from_stock ( GTK_STOCK_EDIT,
-                            GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gtk-edit-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                             "activate",
                             G_CALLBACK ( edit_category ),
@@ -1142,10 +1132,7 @@ void category_list_popup_context_menu ( void )
         else
             title = g_strdup ( _("Transfer all transactions in another sub-category") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
-                        GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gsb-convert-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( metatree_manage_sub_divisions ),
@@ -1158,18 +1145,11 @@ void category_list_popup_context_menu ( void )
     /* Finish all. */
     gtk_widget_show_all ( menu );
 
+#if GTK_CHECK_VERSION (3,22,0)
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
+#else
     gtk_menu_popup ( GTK_MENU ( menu ), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time ( ) );
-}
-
-
-/**
- *
- *
- *
- */
-GtkWidget *category_list_get_toolbar ( void )
-{
-    return category_toolbar;
+#endif
 }
 
 
