@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -44,7 +44,6 @@
 #include "transaction_list.h"
 #include "transaction_list_select.h"
 #include "structures.h"
-#include "fenetre_principale.h"
 #include "etats_config.h"
 #include "etats_affiche.h"
 #include "erreur.h"
@@ -53,16 +52,16 @@
 /*START_STATIC*/
 static void gtktable_attach_hsep ( int x, int x2, int y, int y2);
 static void gtktable_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2,
-			     enum alignement align, gint transaction_number );
+								   GtkJustification align, gint transaction_number );
 static void gtktable_attach_vsep ( int x, int x2, int y, int y2);
 static void gtktable_click_sur_ope_etat ( gint transaction_number );
-static gint gtktable_finish ();
+static gint gtktable_finish ( void );
 static gint gtktable_initialise ( GSList * opes_selectionnees, gchar * filename );
 /*END_STATIC*/
 
 GtkWidget *table_etat = NULL;
 
-struct struct_etat_affichage gtktable_affichage = {
+struct EtatAffichage gtktable_affichage = {
     gtktable_initialise,
     gtktable_finish,
     gtktable_attach_hsep,
@@ -74,7 +73,6 @@ struct struct_etat_affichage gtktable_affichage = {
 
 
 /*START_EXTERN*/
-extern gint nb_colonnes;
 extern GtkWidget *scrolled_window_etat;
 /*END_EXTERN*/
 
@@ -94,10 +92,14 @@ extern GtkWidget *scrolled_window_etat;
  *				an hyperlink if applicable
  */
 void gtktable_attach_label ( gchar * text, gdouble properties, int x, int x2, int y, int y2,
-			     enum alignement align, gint transaction_number )
+							GtkJustification align, gint transaction_number )
 {
     GtkWidget * label;
-    GtkStyle * style;
+	PangoContext *p_context;
+	PangoFontDescription *font_desc;
+
+	gint x_dim;
+    gint y_dim;
 
     if (!text)
     {
@@ -109,78 +111,71 @@ void gtktable_attach_label ( gchar * text, gdouble properties, int x, int x2, in
 
     switch (align)
     {
-	case ALIGN_LEFT:
-	    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-	    break;
-	case ALIGN_CENTER:
-	    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.5, 0.0 );
-	    break;
-	case ALIGN_RIGHT:
-	    gtk_misc_set_alignment ( GTK_MISC ( label ), 1.0, 0.0 );
-	    break;
+		case GTK_JUSTIFY_LEFT:
+			utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+			break;
+		case GTK_JUSTIFY_CENTER:
+			utils_labels_set_alignment ( GTK_LABEL ( label ), 0.5, 0.0 );
+			break;
+		case GTK_JUSTIFY_RIGHT:
+			utils_labels_set_alignment ( GTK_LABEL ( label ), 1.0, 0.0 );
+			break;
+		case GTK_JUSTIFY_FILL:
+			break;
     }
 
-    style = gtk_style_copy ( gtk_widget_get_style (label));
-
     if (transaction_number)
     {
-	GtkWidget *event_box;
-	GdkColor color;
+		GtkWidget *event_box;
+		GtkStyleContext* context;
 
-	/* Put prelight */
-	color.red =   1.00 * 65535 ;
-	color.green = 0.00 * 65535 ;
-	color.blue =  0.00 * 65535 ;
-	color.pixel = 0;
-	style->fg[GTK_STATE_PRELIGHT] = color;
+		event_box = gtk_event_box_new ();
+		gtk_widget_set_name (event_box, "etat_event_box");
+		context = gtk_widget_get_style_context  (event_box);
+		gtk_style_context_set_state ( context, GTK_STATE_FLAG_ACTIVE );
+		g_signal_connect (G_OBJECT (event_box),
+						  "enter_notify_event",
+						  G_CALLBACK (utils_event_box_change_state),
+						  context);
+		g_signal_connect (G_OBJECT (event_box),
+						  "leave_notify_event",
+						  G_CALLBACK (utils_event_box_change_state),
+						  context);
+		g_signal_connect_swapped ( G_OBJECT ( event_box ),
+						"button_press_event",
+						G_CALLBACK ( gtktable_click_sur_ope_etat ),
+						GINT_TO_POINTER (transaction_number) );
+		x_dim = x2 - x;
+		y_dim = y2 - y;
+		gtk_grid_attach (GTK_GRID (table_etat), event_box, x, y, x_dim, y_dim);
+		g_object_set_data (G_OBJECT (event_box), "x_dim", GINT_TO_POINTER (x_dim));
 
-	event_box = gtk_event_box_new ();
-	g_signal_connect ( G_OBJECT ( event_box ),
-			     "enter_notify_event",
-			     G_CALLBACK ( met_en_prelight ),
-			     NULL );
-	g_signal_connect ( G_OBJECT ( event_box ),
-			     "leave_notify_event",
-			     G_CALLBACK ( met_en_normal ),
-			     NULL );
-	g_signal_connect_swapped ( G_OBJECT ( event_box ),
-				    "button_press_event",
-				    G_CALLBACK ( gtktable_click_sur_ope_etat ),
-				    (GtkObject *) GINT_TO_POINTER (transaction_number) );
-	gtk_table_attach ( GTK_TABLE ( table_etat ), event_box,
-			   x, x2, y, y2,
-			   GTK_SHRINK | GTK_FILL,
-			   GTK_SHRINK | GTK_FILL,
-			   0, 0 );
-	gtk_widget_show ( event_box );
-	gtk_container_add ( GTK_CONTAINER ( event_box ), label );
+		gtk_widget_show ( event_box );
+		gtk_container_add ( GTK_CONTAINER ( event_box ), label );
     }
     else
     {
-	gtk_table_attach ( GTK_TABLE ( table_etat ), label,
-			   x, x2, y, y2,
-			   GTK_SHRINK | GTK_FILL,
-			   GTK_SHRINK | GTK_FILL,
-			   0, 0 );
+        x_dim = x2 - x;
+        y_dim = y2 - y;
+        gtk_grid_attach (GTK_GRID (table_etat), label, x, y, x_dim, y_dim);
+		g_object_set_data (G_OBJECT (label), "x_dim", GINT_TO_POINTER (x_dim));
     }
+	p_context = gtk_widget_get_pango_context (label);
+	font_desc = pango_context_get_font_description (p_context);
 
-    if ( ((gint) properties) & TEXT_ITALIC)
-	pango_font_description_set_style ( style -> font_desc,
-					   PANGO_STYLE_ITALIC );
-    if ( ((gint) properties) & TEXT_BOLD)
-	pango_font_description_set_weight ( style -> font_desc,
-					    PANGO_WEIGHT_BOLD );
-    if ( ((gint) properties) & TEXT_HUGE )
-	pango_font_description_set_size ( style -> font_desc,
-					  pango_font_description_get_size(style->font_desc) + 100 );
-    if ( ((gint) properties) & TEXT_LARGE )
-	pango_font_description_set_size ( style -> font_desc,
-					  pango_font_description_get_size(style->font_desc) + 2 );
-    if ( ((gint) properties) & TEXT_SMALL )
-	pango_font_description_set_size ( style -> font_desc,
-					  pango_font_description_get_size(style->font_desc) - 2 );
-
-    gtk_widget_set_style ( label, style );
+    if (((gint) properties) & TEXT_ITALIC)
+		pango_font_description_set_style (font_desc, PANGO_STYLE_ITALIC);
+    if (((gint) properties) & TEXT_BOLD)
+		pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
+    if (((gint) properties) & TEXT_HUGE)
+	pango_font_description_set_size (font_desc,
+	                                 pango_font_description_get_size (font_desc) + 100);
+    if (((gint) properties) & TEXT_LARGE)
+	pango_font_description_set_size (font_desc,
+	                                 pango_font_description_get_size (font_desc) + 2);
+    if (((gint) properties) & TEXT_SMALL)
+	pango_font_description_set_size (font_desc,
+	                                 pango_font_description_get_size (font_desc) - 2);
     gtk_widget_show ( label );
 }
 
@@ -202,15 +197,17 @@ void gtktable_attach_label ( gchar * text, gdouble properties, int x, int x2, in
 void gtktable_attach_vsep ( int x, int x2, int y, int y2)
 {
     GtkWidget * separateur;
+    gint x_dim;
+    gint y_dim;
 
-    separateur = gtk_vseparator_new ();
-    gtk_table_attach ( GTK_TABLE ( table_etat ),
-		       separateur,
-		       x, x2, y, y2,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       2, 0 );
-    gtk_widget_show ( separateur );
+    separateur = gtk_separator_new ( GTK_ORIENTATION_VERTICAL );
+    x_dim = x2 - x;
+    y_dim = y2 - y;
+    gtk_grid_attach (GTK_GRID (table_etat), separateur, x, y, x_dim, y_dim);
+    utils_widget_set_padding ( separateur, 2,0);
+	g_object_set_data (G_OBJECT (separateur), "type_separator", GINT_TO_POINTER (GTK_ORIENTATION_VERTICAL));
+
+	gtk_widget_show ( separateur );
 }
 
 
@@ -225,15 +222,16 @@ void gtktable_attach_vsep ( int x, int x2, int y, int y2)
 void gtktable_attach_hsep ( int x, int x2, int y, int y2)
 {
     GtkWidget * separateur;
+    gint x_dim;
+    gint y_dim;
 
-    separateur = gtk_hseparator_new ();
-    gtk_table_attach ( GTK_TABLE ( table_etat ),
-		       separateur,
-		       x, x2, y, y2,
-		       GTK_SHRINK | GTK_FILL,
-		       GTK_SHRINK | GTK_FILL,
-		       0, 0 );
-    gtk_widget_show ( separateur );
+    separateur = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
+    x_dim = x2 - x;
+    y_dim = y2 - y;
+    gtk_grid_attach (GTK_GRID (table_etat), separateur, x, y, x_dim, y_dim);
+	g_object_set_data (G_OBJECT (separateur), "type_separator", GINT_TO_POINTER (GTK_ORIENTATION_HORIZONTAL));
+
+	gtk_widget_show ( separateur );
 }
 
 
@@ -244,18 +242,19 @@ gint gtktable_initialise ( GSList * opes_selectionnees, gchar * filename )
     /* on peut maintenant créer la table */
     /* pas besoin d'indiquer la hauteur, elle grandit automatiquement */
 
-    if ( table_etat && GTK_IS_TABLE(table_etat) )
-	gtk_widget_destroy (table_etat);
+    if (table_etat && GTK_IS_GRID (table_etat))
+        gtk_widget_destroy (table_etat);
 
-    if ( scrolled_window_etat && GTK_BIN ( scrolled_window_etat ) -> child )
-	gtk_widget_hide ( GTK_BIN ( scrolled_window_etat ) -> child );
+    /* regarder la liberation de mémoire */
+    if ( scrolled_window_etat && gtk_bin_get_child ( GTK_BIN ( scrolled_window_etat ) ) )
+        gtk_widget_destroy ( gtk_bin_get_child ( GTK_BIN ( scrolled_window_etat ) ) );
 
     /* just update screen so that the user does not see the previous report anymore
      * while we are processing the new report */
-/*     update_gui ( );  */
+     update_gui ( );
 
-    table_etat = gtk_table_new ( 0, nb_colonnes, FALSE );
-    gtk_table_set_col_spacings ( GTK_TABLE ( table_etat ), 5 );
+    table_etat = gtk_grid_new ();
+    gtk_grid_set_column_spacing (GTK_GRID (table_etat), 5);
 
     return 1;
 }
@@ -263,16 +262,16 @@ gint gtktable_initialise ( GSList * opes_selectionnees, gchar * filename )
 
 
 /*****************************************************************************************************/
-gint gtktable_finish ()
+gint gtktable_finish ( void )
 {
-    gtk_scrolled_window_add_with_viewport ( GTK_SCROLLED_WINDOW ( scrolled_window_etat ), table_etat );
+    gtk_container_add ( GTK_CONTAINER ( scrolled_window_etat ), table_etat );
     gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW ( scrolled_window_etat ), GTK_SHADOW_NONE );
 
     gtk_container_set_border_width ( GTK_CONTAINER ( table_etat ), 6 );
     gtk_widget_show_all ( table_etat );
 
-    if ( GTK_BIN ( scrolled_window_etat ) -> child )
-	gtk_widget_show ( GTK_BIN ( scrolled_window_etat ) -> child );
+    if ( gtk_bin_get_child ( GTK_BIN ( scrolled_window_etat ) ) )
+        gtk_widget_show ( gtk_bin_get_child ( GTK_BIN ( scrolled_window_etat ) ) );
 
     return 1;
 }
@@ -306,9 +305,7 @@ void gtktable_click_sur_ope_etat ( gint transaction_number )
 	gint mother_transaction;
 
 	/* go on the good account */
-	gsb_gui_navigation_set_selection ( GSB_ACCOUNT_PAGE,
-					   account_number,
-					   GINT_TO_POINTER (-1));
+	gsb_gui_navigation_set_selection ( GSB_ACCOUNT_PAGE, account_number, -1);
 
 	/* récupération de la ligne de l'opé dans la liste ; affichage de toutes les opé si nécessaire */
 	if ( gsb_data_transaction_get_marked_transaction (transaction_number) == OPERATION_RAPPROCHEE
