@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -35,18 +35,20 @@
 
 /*START_INCLUDE*/
 #include "gsb_assistant_file.h"
-#include "affichage.h"
+#include "grisbi_app.h"
 #include "gsb_assistant.h"
 #include "gsb_automem.h"
 #include "gsb_bank.h"
 #include "gsb_category.h"
 #include "gsb_currency_config.h"
 #include "gsb_currency.h"
+#include "gsb_data_form.h"
 #include "gsb_dirs.h"
 #include "gsb_file.h"
 #include "gsb_select_icon.h"
 #include "import.h"
 #include "parametres.h"
+#include "structures.h"
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_str.h"
@@ -54,7 +56,7 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
+static void gsb_assistant_file_change_title ( GtkWidget *title_entry,
 						  GtkWidget *filename_entry );
 static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
 						     GtkWidget *entry );
@@ -67,9 +69,6 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gchar *adresse_commune;
-extern gchar *nom_fichier_comptes;
-extern gchar *titre_fichier;
 /*END_EXTERN*/
 
 enum file_assistant_page
@@ -79,7 +78,7 @@ enum file_assistant_page
     FILE_ASSISTANT_PAGE_3,
     FILE_ASSISTANT_PAGE_4,
     FILE_ASSISTANT_PAGE_5,
-    FILE_ASSISTANT_PAGE_FINISH,
+    FILE_ASSISTANT_PAGE_FINISH
 };
 
 /* the box containing the currencies list
@@ -89,7 +88,8 @@ static GtkWidget *currency_list_box;
 /* the button to know what assistant to launch at the end */
 static GtkWidget *button_create_account_next;
 
-
+/* nom du fichier de compte créé PROVISOIRE */
+static gchar *nom_fichier_comptes;
 
 /**
  * this function is called to launch the file opening assistant
@@ -104,13 +104,18 @@ static GtkWidget *button_create_account_next;
 GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 					 gboolean import )
 {
-    GtkResponseType return_value;
     GtkWidget *assistant;
-    gchar *currency_name, *currency_iso_code, *currency_nickname;
-    gint currency_floating;
     GtkTreeIter iter;
+	GtkTreeSelection *selection;
+	GtkTreeView *tree_view;
+    GtkResponseType return_value;
+    gchar *currency_iso_code;
+    gchar *currency_name;
+    gchar *currency_nickname;
+    const gchar *text_1;
+    const gchar *text_2;
+    gint currency_floating;
     gboolean launch_account_assistant;
-    const gchar *text_1, *text_2;
 
     /* create the assistant */
     if (first_opening)
@@ -149,7 +154,7 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
     }
 
     assistant = gsb_assistant_new (text_1, text_2,
-				   "grisbi.png", NULL);
+				   "gsb-new-file-32.png", NULL);
 
     gsb_assistant_add_page ( assistant,
 			     gsb_assistant_file_page_2 (assistant),
@@ -187,34 +192,41 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 
     if (return_value == GTK_RESPONSE_CANCEL)
     {
-	/* the user stopped the assistant, we delete all the configured data */
-	init_variables ();
-	gtk_widget_destroy (assistant);
-	return return_value;
+		/* the user stopped the assistant, we delete all the configured data */
+		init_variables ();
+		gtk_widget_destroy (assistant);
+		grisbi_win_stack_box_show (NULL, "accueil_page");
+		return return_value;
     }
 
     /* the assistant is finished, we save the values not saved before */
 
     /* get the currency */
-    if (gtk_tree_selection_get_selected ( gtk_tree_view_get_selection (GTK_TREE_VIEW (g_object_get_data (G_OBJECT (currency_list_box),
-													 "treeview"))),
-					  NULL,
-					  &iter ))
+	tree_view = GTK_TREE_VIEW (g_object_get_data (G_OBJECT (currency_list_box), "tree_view"));
+	selection = gtk_tree_view_get_selection (tree_view);
+    if (gtk_tree_selection_get_selected (selection, NULL, &iter))
     {
-	/* there is a selection, normaly, always the case */
-	gtk_tree_model_get ( GTK_TREE_MODEL (g_object_get_data(G_OBJECT (currency_list_box),
-							       "model")),
-			     &iter,
-			     CURRENCY_NAME_COLUMN, &currency_name,
-			     CURRENCY_ISO_CODE_COLUMN, &currency_iso_code,
-			     CURRENCY_NICKNAME_COLUMN, &currency_nickname,
-			     CURRENCY_FLOATING_COLUMN, &currency_floating,
-			     -1 );
-	gsb_currency_config_create_currency ( currency_name, currency_nickname,
-					      currency_iso_code, currency_floating);
+		GtkTreeModel *model;
 
-	/* update the currency list for combobox */
-	gsb_currency_update_combobox_currency_list ();
+		model = gtk_tree_view_get_model (tree_view);
+	/* there is a selection, normaly, always the case */
+		gtk_tree_model_get (model,
+							&iter,
+							CURRENCY_NAME_COLUMN, &currency_name,
+							CURRENCY_ISO_CODE_COLUMN, &currency_iso_code,
+							CURRENCY_NICKNAME_COLUMN, &currency_nickname,
+							CURRENCY_FLOATING_COLUMN, &currency_floating,
+							-1);
+		gsb_currency_config_create_currency (currency_name,
+											 currency_nickname,
+											 currency_iso_code,
+											 currency_floating);
+
+		/* update the currency list for combobox */
+		gsb_currency_update_combobox_currency_list ();
+		g_free (currency_name);
+		g_free (currency_nickname);
+		g_free (currency_iso_code);
     }
 
     /* create the list of categories
@@ -230,11 +242,16 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
     gsb_select_icon_set_logo_pixbuf (
                         gsb_select_icon_get_default_logo_pixbuf ( ) );
 
+	/* set the new filename */
+	grisbi_win_set_filename (NULL, nom_fichier_comptes);
+	if (nom_fichier_comptes)
+		g_free (nom_fichier_comptes);
+
     /* and now, launch the next assistant */
     if (launch_account_assistant)
 	gsb_file_new_finish ();
     else
-	importer_fichier ();
+	gsb_import_assistant_importer_fichier ();
 
     return return_value;
 }
@@ -242,7 +259,7 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
 
 
 /**
- * create the page 3 of the first assistant
+ * create the page 2 of the first assistant
  * we create here the title of the file, name of the file and adress
  *
  * \param assistant the GtkWidget assistant
@@ -261,21 +278,25 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
     GtkWidget *button;
     GtkWidget *table;
     GtkWidget *filename_entry;
+	GrisbiWinEtat *w_etat;
+	GrisbiWinRun *w_run;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+	w_etat = grisbi_win_get_w_etat ();
+	w_run = grisbi_win_get_w_run ();
+
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 15 );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     vbox = new_vbox_with_title_and_icon ( _("General configuration"),
-					  "payees.png" );
+					  "gsb-payees-32.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 TRUE, TRUE, 0 );
 
 	/* table 2x3 for layout */
-	table = gtk_table_new ( 2, 3, FALSE );
-	gtk_table_set_row_spacings ( GTK_TABLE ( table ), 6 );
-	gtk_table_set_col_spacings ( GTK_TABLE ( table ), 6 );
+    table = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (table), 6);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 6);
 
 	/* Account file title */
 	paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Titles and filenames") );
@@ -283,66 +304,71 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 
 	/* label account name */
 	label = gtk_label_new ( _("Name of accounting entity: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
 	/* need to declare filename_entry first for the next callback,
 	 * if no filename, set the title.gsb as default name */
+	nom_fichier_comptes = g_strdup (grisbi_win_get_filename (NULL));
 	if (!nom_fichier_comptes)
 	nom_fichier_comptes = g_strconcat ( gsb_dirs_get_default_dir (),
-			G_DIR_SEPARATOR_S, titre_fichier, ".gsb", NULL );
-	filename_entry = gsb_automem_entry_new (&nom_fichier_comptes,
-			NULL, NULL);
+			G_DIR_SEPARATOR_S, _("My accounts"), ".gsb", NULL );
+	filename_entry = gsb_automem_entry_new (&nom_fichier_comptes, NULL, NULL);
+	gtk_widget_set_hexpand (filename_entry, TRUE);
 
-	entry = gsb_automem_entry_new (&titre_fichier,
-			((GCallback)gsb_assistant_file_change_title), filename_entry);
-	g_object_set_data ( G_OBJECT (entry),
-			"last_title", my_strdup (titre_fichier));
-	gtk_table_attach ( GTK_TABLE ( table ), entry, 1, 3, 0, 1,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+    entry = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY(entry), _("My accounts"));
+	w_etat->accounting_entity = my_strdup (_("My accounts"));
+	g_signal_connect (G_OBJECT(entry),
+					  "changed",
+					  G_CALLBACK (gsb_assistant_file_change_title),
+					  filename_entry);
+	g_object_set_data_full (G_OBJECT (entry),
+							"last_title",
+							my_strdup (w_etat->accounting_entity),
+							g_free);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, 0, 2, 1);
 
 	/* filename */
 	label = gtk_label_new ( _("Filename: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+	utils_labels_set_alignment ( GTK_LABEL (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
-	gtk_table_attach ( GTK_TABLE ( table ), filename_entry, 1, 2, 1, 2,
-			GTK_EXPAND | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), filename_entry, 1, 1, 1, 1);
 
 	button = gtk_button_new_with_label ("...");
 	gtk_button_set_relief ( GTK_BUTTON (button), GTK_RELIEF_NONE );
 	g_signal_connect ( G_OBJECT (button), "clicked",
 			G_CALLBACK (gsb_assistant_file_choose_filename), filename_entry );
 
-	gtk_table_attach ( GTK_TABLE ( table ), button, 2, 3, 1, 2,
-			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), button, 2, 1, 1, 1);
 
     /* will we crypt the file ? */
 #ifdef HAVE_SSL
     {
-        button = gsb_automem_checkbutton_new ( _("Encrypt Grisbi file"),
-                                               &(etat.crypt_file), G_CALLBACK (gsb_gui_encryption_toggled), NULL);
+        button = gsb_automem_checkbutton_new (_("Encrypt Grisbi file"),
+											  &w_etat->crypt_file,
+											  G_CALLBACK (gsb_gui_encryption_toggled),
+											  NULL);
         gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
                              FALSE, FALSE, 0 );
 
-        if ( etat.crypt_file )
-            run.new_crypted_file = TRUE;
+        if (w_etat->crypt_file )
+            w_run->new_crypted_file = TRUE;
     }
 #else
     {
-        run.new_crypted_file = FALSE;
+        w_run->new_crypted_file = FALSE;
     }
 #endif
 
     /* date format */
-    paddingbox = gsb_config_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+    gsb_config_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
 
     /* decimal and thousands separator */
-    paddingbox = gsb_config_number_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
+    gsb_config_number_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
 
     /* Address */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Your address") );
@@ -356,16 +382,20 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 			 FALSE, FALSE, 0);
     gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scrolled_window),
 					  GTK_SHADOW_IN );
-    textview = gsb_automem_textview_new ( &adresse_commune, NULL, NULL );
+    textview = gsb_automem_textview_new ( &w_etat->adr_common, NULL, NULL );
     gtk_container_add ( GTK_CONTAINER ( scrolled_window ),
 			textview );
 
+	/* set the new form organization */
+    gsb_data_form_new_organization ();
+    gsb_data_form_set_default_organization ();
+
     gtk_widget_show_all (page);
     return page;
 }
 
 /**
- * create the page 4 of the first assistant
+ * create the page 3 of the first assistant
  * we create here the first currency for the software
  *
  * \param assistant the GtkWidget assistant
@@ -377,12 +407,11 @@ static GtkWidget *gsb_assistant_file_page_3 ( GtkWidget *assistant )
     GtkWidget *page;
     GtkWidget *vbox;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     vbox = new_vbox_with_title_and_icon ( _("Select base currency"),
-					  "currencies.png" );
+					  "gsb-currencies-32.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 TRUE, TRUE, 0 );
@@ -396,14 +425,14 @@ static GtkWidget *gsb_assistant_file_page_3 ( GtkWidget *assistant )
     /* Select default currency. */
     gtk_tree_model_foreach ( GTK_TREE_MODEL(g_object_get_data ( G_OBJECT(currency_list_box), "model" )),
 			     (GtkTreeModelForeachFunc) gsb_currency_config_select_default,
-			     g_object_get_data ( G_OBJECT(currency_list_box), "treeview" ) );
+			     g_object_get_data ( G_OBJECT(currency_list_box), "tree_view" ) );
 
     gtk_widget_show_all (page);
     return page;
 }
 
 /**
- * create the page 5 of the first assistant
+ * create the page 4 of the first assistant
  * selection of the list of categories
  *
  * \param assistant the GtkWidget assistant
@@ -416,12 +445,11 @@ static GtkWidget *gsb_assistant_file_page_4 ( GtkWidget *assistant )
     GtkWidget *vbox;
     GtkWidget *button_list;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     vbox = new_vbox_with_title_and_icon ( _("Select the list of categories you will use"),
-					  "categories.png" );
+					  "gsb-categories-32.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 TRUE, TRUE, 0 );
@@ -436,7 +464,7 @@ static GtkWidget *gsb_assistant_file_page_4 ( GtkWidget *assistant )
 }
 
 /**
- * create the page 6 of the first assistant
+ * create the page 5 of the first assistant
  * Creation of the banks
  *
  * \param assistant the GtkWidget assistant
@@ -448,12 +476,11 @@ static GtkWidget *gsb_assistant_file_page_5 ( GtkWidget *assistant )
     GtkWidget *page;
     GtkWidget *bank_page;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     /* the configuration page is very good, keep it */
-    bank_page = gsb_bank_create_page (TRUE);
+    bank_page = gsb_bank_create_page (TRUE, 130);
     gtk_box_pack_start ( GTK_BOX (page),
 			 bank_page,
 			 TRUE, TRUE, 0 );
@@ -479,12 +506,11 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
     GtkWidget *label;
     GtkWidget *button;
 
-    page = gtk_hbox_new (FALSE, 15);
-    gtk_container_set_border_width ( GTK_CONTAINER (page),
-				     10 );
+    page = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
+    gtk_container_set_border_width ( GTK_CONTAINER (page), BOX_BORDER_WIDTH );
 
     vbox = new_vbox_with_title_and_icon ( _("Configuration finished!"),
-					  "reconciliationlg.png" );
+					  "reconciliation-32.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
 			 TRUE, TRUE, 0 );
@@ -494,7 +520,7 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
 			     "Next assistant will help you creating a new account.\n\n"
 			     "Remember that all of the values can be changed in the 'Preferences' dialog.\n\n"
 			     "Select a way to populate your account file and press the 'Close' button."));
-    gtk_misc_set_alignment ( GTK_MISC (label),
+    utils_labels_set_alignment ( GTK_LABEL (label),
 			     0, 0.5 );
     gtk_box_pack_start ( GTK_BOX (vbox),
 			 label,
@@ -530,14 +556,23 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
  *
  * \return FALSE
  * */
-static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
+static void gsb_assistant_file_change_title ( GtkWidget *title_entry,
 						  GtkWidget *filename_entry )
 {
     gchar *new_filename;
     gchar *last_filename;
     gchar *last_title;
+	const gchar *text;
+	GrisbiWinEtat *w_etat;
 
-    update_homepage_title (GTK_ENTRY (title_entry), NULL, 0, 0);
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+
+	text = gtk_entry_get_text (GTK_ENTRY (title_entry));
+	if (text && strlen (text))
+		w_etat->accounting_entity = g_strdup (text);
+
+    /* set Grisbi title */
+    grisbi_win_set_window_title (-1);
 
     /* first get the last content of the title to see if the filename
      * was automatically created, and in that case, we continue the automatic mode,
@@ -550,7 +585,6 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
 				  ".gsb",
 				  NULL );
     /* set the new -last title- */
-    g_free (last_title);
     g_object_set_data ( G_OBJECT (title_entry),
 			"last_title", g_strdup (gtk_entry_get_text (GTK_ENTRY (title_entry))));
 
@@ -560,7 +594,7 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
 	/* there is a difference between the last title and the filename,
 	 * so juste free the memory and do nothing */
 	g_free (last_filename);
-	return FALSE;
+	return;
     }
 
     /* ok, the filename is an automatic creation,
@@ -588,7 +622,7 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
 			 new_filename );
     g_free (new_filename);
 
-    return FALSE;
+    return;
 }
 
 /**
@@ -607,10 +641,10 @@ static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
     gchar *tmpstr;
 
     dialog = gtk_file_chooser_dialog_new ( _("Create filename"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-ok", GTK_RESPONSE_ACCEPT,
 					   NULL);
 
     tmpstr = g_path_get_basename (gtk_entry_get_text (GTK_ENTRY (entry)));
