@@ -28,7 +28,7 @@
  * */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -38,7 +38,7 @@
 
 /*START_INCLUDE*/
 #include "gsb_calendar_entry.h"
-#include "gsb_color.h"
+#include "grisbi_app.h"
 #include "gsb_form_widget.h"
 #include "structures.h"
 #include "utils_dates.h"
@@ -181,19 +181,18 @@ gboolean gsb_calendar_entry_set_color ( GtkWidget *entry,
 					gboolean normal_color )
 {
     if (!entry)
-	return FALSE;
+        return FALSE;
 
     if (normal_color)
     {
-	gtk_widget_modify_base ( entry,
-				 GTK_STATE_NORMAL,
-				 NULL );
+		if (gsb_form_widget_check_empty (entry))
+			gtk_widget_set_name (entry, "form_entry_empty");
+		else
+        	gtk_widget_set_name (entry, "form_entry");
     }
     else
     {
-	gtk_widget_modify_base ( entry,
-				 GTK_STATE_NORMAL,
-				 gsb_color_get_couleur ( "entry_error_color" ) );
+        gtk_widget_set_name (entry, "form_entry_error");
     }
 
     return FALSE;
@@ -205,7 +204,7 @@ gboolean gsb_calendar_entry_set_color ( GtkWidget *entry,
  * callback called when press button on the date entry
  * used to popup a calendar if double click
  *
- * \param entry the entry wich receive the signal
+ * \param entry the entry which receive the signal
  * \param event
  * \param null not used
  *
@@ -226,7 +225,7 @@ gboolean gsb_calendar_entry_button_press ( GtkWidget *entry,
  * callback called when press a key on the date entry
  * used to increase/decrease the date and popup the calendar
  *
- * \param entry the entry wich receive the signal
+ * \param entry the entry which receive the signal
  * \param event
  * \param null not used
  *
@@ -238,41 +237,48 @@ gboolean gsb_calendar_entry_key_press ( GtkWidget *entry,
 {
     switch ( ev -> keyval )
     {
-	case GDK_KP_Enter :
-	case GDK_Return :
+	case GDK_KEY_KP_Enter :
+	case GDK_KEY_Return :
 
 	    /* CONTROL ENTER opens the calendar */
 	    if ( ( ev -> state & GDK_CONTROL_MASK ) == GDK_CONTROL_MASK)
 		gsb_calendar_entry_popup (entry);
 	    break;
 
-	case GDK_KP_Add:
-	case GDK_plus:
-	case GDK_equal:		/* This should make all our US users happy */
+	case GDK_KEY_KP_Add:
+	case GDK_KEY_plus:
+	case GDK_KEY_equal:		/* This should make all our US users happy */
 
 	    /* increase the date of 1 day/week */
 	    if ( ( ev -> state & GDK_CONTROL_MASK ) != GDK_CONTROL_MASK ||
-		 ev -> keyval != GDK_KP_Add )
+		 ev -> keyval != GDK_KEY_KP_Add )
 		gsb_calendar_entry_step_date ( entry, ONE_DAY );
 	    else
 		gsb_calendar_entry_step_date ( entry, ONE_WEEK );
 	    return TRUE;
 	    break;
 
-	case GDK_KP_Subtract:
-	case GDK_minus:
+	case GDK_KEY_KP_Subtract:
+	case GDK_KEY_minus:
+		{
+			const gchar *date_format;
 
-	    /* decrease the date of 1 day/week, or the check of 1 */
-	    if ( ( ev -> state & GDK_CONTROL_MASK ) != GDK_CONTROL_MASK ||
-		 ev -> keyval != GDK_KP_Subtract  )
-		gsb_calendar_entry_step_date ( entry, -ONE_DAY );
-	    else
-		gsb_calendar_entry_step_date ( entry, -ONE_WEEK );
-	    return TRUE;
-	    break;
+			date_format = gsb_date_get_format_date ();
+			if (g_strcmp0 (date_format, "%Y-%m-%d"))
+			{
+				/* decrease the date of 1 day/week, or the check of 1 */
+				if ( ( ev -> state & GDK_CONTROL_MASK ) != GDK_CONTROL_MASK ||
+				 ev -> keyval != GDK_KEY_KP_Subtract  )
+					gsb_calendar_entry_step_date ( entry, -ONE_DAY );
+				else
+					gsb_calendar_entry_step_date ( entry, -ONE_WEEK );
+				return TRUE;
+			}
+			break;
+		}
 
-	case GDK_Page_Up :
-	case GDK_KP_Page_Up :
+	case GDK_KEY_Page_Up :
+	case GDK_KEY_KP_Page_Up :
 
 	    /* increase the date of 1 month/year */
 	    if ( ( ev -> state & GDK_CONTROL_MASK ) != GDK_CONTROL_MASK )
@@ -285,8 +291,8 @@ gboolean gsb_calendar_entry_key_press ( GtkWidget *entry,
 	    return TRUE;
 	    break;
 
-	case GDK_Page_Down :
-	case GDK_KP_Page_Down :
+	case GDK_KEY_Page_Down :
+	case GDK_KEY_KP_Page_Down :
 
 	    /* decrease the date of 1 month/year */
 	    if ( ( ev -> state & GDK_CONTROL_MASK ) != GDK_CONTROL_MASK )
@@ -373,7 +379,7 @@ void gsb_calendar_entry_step_date ( GtkWidget *entry,
  * callback called on focus-out on the date entry
  * complete and check the date
  *
- * \param entry the entry wich receive the signal
+ * \param entry the entry which receive the signal
  * \param event
  * \param set_today TRUE (but pointer) if we want to set the current day if the entry is left empty
  *
@@ -440,33 +446,29 @@ gboolean gsb_calendar_entry_changed ( GtkWidget *entry,
  *
  * \param entry the date entry
  *
- * \return a GtkWindow wich contains the calendar
+ * \return a GtkWindow which contains the calendar
  * */
 GtkWidget *gsb_calendar_entry_popup ( GtkWidget *entry )
 {
     GtkWidget *popup, *pVBox, *pCalendar, *button, *frame;
-    GtkRequisition *popup_size;
+	GdkWindow *window;
+    GtkRequisition popup_size;
     gint x, y;
-    gint screen_width = gdk_screen_width ( );
     GDate * date;
 
     /* make the popup */
     popup = gtk_window_new ( GTK_WINDOW_TOPLEVEL );
     gtk_window_set_modal ( GTK_WINDOW ( popup ), TRUE );
     gtk_window_set_transient_for ( GTK_WINDOW ( popup ),
-                        GTK_WINDOW ( run.window ) );
+                        GTK_WINDOW ( grisbi_app_get_active_window (NULL) ) );
     gtk_window_set_decorated ( GTK_WINDOW ( popup ), FALSE );
-    g_signal_connect_swapped ( G_OBJECT ( popup ),
-				"destroy",
-				G_CALLBACK ( gdk_pointer_ungrab ),
-				GDK_CURRENT_TIME );
 
     /* set the decoration */
     frame = gtk_frame_new ( NULL );
     gtk_container_add ( GTK_CONTAINER ( popup ), frame );
     gtk_widget_show ( frame );
 
-    pVBox = gtk_vbox_new ( FALSE, 5 );
+    pVBox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
     gtk_container_set_border_width ( GTK_CONTAINER ( pVBox ), 5 );
     gtk_container_add ( GTK_CONTAINER ( frame ), pVBox );
     gtk_widget_show ( pVBox );
@@ -512,20 +514,34 @@ GtkWidget *gsb_calendar_entry_popup ( GtkWidget *entry )
     gtk_widget_show ( button );
 
     /* set the position */
-    gdk_window_get_origin ( GTK_WIDGET ( entry ) -> window,
-			    &x,
-			    &y );
+	window = gtk_widget_get_window (GTK_WIDGET (entry));
+    gdk_window_get_origin (window, &x, &y );
 
     /* on récupère la taille de la popup */
-    popup_size = g_malloc0 ( sizeof ( GtkRequisition ));
-    gtk_widget_size_request ( GTK_WIDGET ( popup ), popup_size );
+    gtk_widget_get_preferred_size (GTK_WIDGET (popup), &popup_size, NULL);
 
     /* pour la soustraire à la position de l'entrée date */
-    y -= popup_size -> height;
+    y -= popup_size.height;
+
+#if GTK_CHECK_VERSION (3,22,0)
+	GdkDisplay *display;
+	GdkMonitor *monitor;
+	GdkRectangle rectangle;
+
+	display = gdk_window_get_display (window);
+	monitor = gdk_display_get_monitor_at_point (display, x, y);
+	gdk_monitor_get_geometry (monitor, &rectangle);
 
     /* on décale le popup si on est trop près de bord droit de l'écran */
-    if ( x > ( screen_width - popup_size -> width ) )
-        x = screen_width - popup_size -> width - 10;
+    if (x > (rectangle.width - popup_size.width))
+        x = rectangle.width - popup_size.width - 10;
+#else
+    gint screen_width = gdk_screen_width ( );
+
+    /* on décale le popup si on est trop près de bord droit de l'écran */
+    if ( x > ( screen_width - popup_size.width ) )
+        x = screen_width - popup_size.width - 10;
+#endif
 
     /* si une des coordonnées est négative, alors la fonction
        gtk_window_move échoue et affiche la popup en 0,0 */
@@ -565,7 +581,7 @@ gboolean gsb_calendar_entry_select_date ( GtkCalendar *pCalendar,
     gtk_entry_set_text ( GTK_ENTRY ( entry ),
 			 gsb_format_date ( day, month + 1, year ));
     gsb_form_widget_set_empty ( entry, FALSE );
-    if ( GTK_WIDGET_TOPLEVEL ( pTopLevelWidget ) )
+    if ( gtk_widget_is_toplevel ( pTopLevelWidget ) )
         gtk_widget_destroy ( pTopLevelWidget );
 
     return FALSE;
@@ -600,20 +616,20 @@ gboolean gsb_calendar_entry_calendar_key_press ( GtkCalendar *pCalendar,
 
     switch ( ev -> keyval )
     {
-	case GDK_Escape :
+	case GDK_KEY_Escape :
 	    /* just close the calendar if it's a popup */
-	    if ( GTK_WIDGET_TOPLEVEL ( pTopLevelWidget ) )
+	    if ( gtk_widget_is_toplevel ( pTopLevelWidget ) )
 		gtk_widget_destroy ( pTopLevelWidget );
 	    g_date_free (date);
 	    return TRUE;
 	    break ;
 
-	case GDK_Return :
-	case GDK_KP_Enter :
+	case GDK_KEY_Return :
+	case GDK_KEY_KP_Enter :
 	    /* get the date an close the calendar */
 	    gtk_entry_set_text ( GTK_ENTRY ( entry ),
 				 gsb_format_date ( day, month, year ));
-	    if ( GTK_WIDGET_TOPLEVEL ( pTopLevelWidget ) )
+	    if ( gtk_widget_is_toplevel ( pTopLevelWidget ) )
 		gtk_widget_destroy ( pTopLevelWidget );
 	    g_date_free (date);
 	    return TRUE;
@@ -622,55 +638,55 @@ gboolean gsb_calendar_entry_calendar_key_press ( GtkCalendar *pCalendar,
 	    /* from now, it will change date so just use date, modify it and fill day, month, year
 	     * we will set the calendar at the end of that function
 	     * so after now, only keys which change the date */
-	case GDK_Left :
-	case GDK_KP_Left:
-	case GDK_minus:
-	case GDK_KP_Subtract:
+	case GDK_KEY_Left :
+	case GDK_KEY_KP_Left:
+	case GDK_KEY_minus:
+	case GDK_KEY_KP_Subtract:
 	    /* day before */
 	    g_date_subtract_days (date, 1);
 	    break ;
 
-	case GDK_Right :
-	case GDK_KP_Right:
-	case GDK_plus:
-	case GDK_KP_Add:
+	case GDK_KEY_Right :
+	case GDK_KEY_KP_Right:
+	case GDK_KEY_plus:
+	case GDK_KEY_KP_Add:
 	    /* day after */
 	    g_date_add_days (date, 1);
 	    break ;
 
-	case GDK_Up :
-	case GDK_KP_Up :
+	case GDK_KEY_Up :
+	case GDK_KEY_KP_Up :
 	    /* prev week */
 	    g_date_subtract_days (date, 7);
 	    break ;
 
-	case GDK_Down :
-	case GDK_KP_Down :
+	case GDK_KEY_Down :
+	case GDK_KEY_KP_Down :
 	    /* next week */
 	    g_date_add_days (date, 7);
 	    break ;
 
-	case GDK_Home :
-	case GDK_KP_Home :
+	case GDK_KEY_Home :
+	case GDK_KEY_KP_Home :
 	    /* go to first day of the month */
 	    g_date_set_day (date, 1);
 	    break ;
 
-	case GDK_End :
-	case GDK_KP_End :
+	case GDK_KEY_End :
+	case GDK_KEY_KP_End :
 	    /* go to last day of the month */
 	    g_date_set_day (date,
 			    g_date_get_days_in_month (month, year));
 	    break ;
 
-	case GDK_Page_Up :
-	case GDK_KP_Page_Up :
+	case GDK_KEY_Page_Up :
+	case GDK_KEY_KP_Page_Up :
 	    /* prev month */
 	    g_date_subtract_months (date, 1);
 	    break ;
 
-	case GDK_Page_Down :
-	case GDK_KP_Page_Down :
+	case GDK_KEY_Page_Down :
+	case GDK_KEY_KP_Page_Down :
 	    /* next month */
 	    g_date_add_months (date, 1);
 	    break ;
