@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -37,8 +37,8 @@
 /*START_INCLUDE*/
 #include "gsb_currency.h"
 #include "dialog.h"
+#include "grisbi_app.h"
 #include "gsb_autofunc.h"
-#include "gsb_color.h"
 #include "gsb_currency_config.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
@@ -56,13 +56,13 @@
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static struct cached_exchange_rate *gsb_currency_config_get_cached_exchange ( gint currency1_number,
+static struct CachedExchangeRate *gsb_currency_config_get_cached_exchange ( gint currency1_number,
                         gint currency2_number );
 static gboolean gsb_currency_checkbutton_link_changed ( GtkWidget *checkbutton,
 						  gboolean *value );
 static void gsb_currency_config_set_cached_exchange ( gint currency1_number,
                         gint currency2_number,
-                        gsb_real change, gsb_real fees );
+                        GsbReal change, GsbReal fees );
 static gboolean gsb_currency_create_combobox_store ( void );
 static GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currency_number,
                         gint account_currency_number,
@@ -81,12 +81,13 @@ static gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
  * used to be set in the combobox */
 static GtkListStore *combobox_currency_store;
 
-enum currency_list_columns {
+enum CurrencyListColumns
+{
     CURRENCY_COL_CODE = 0,
     CURRENCY_COL_NAME,
     CURRENCY_COL_NUMBER,
     CURRENCY_COL_FLAG,
-    CURRENCY_NUM_COL,		/** Number of columns */
+    CURRENCY_NUM_COL		 /** Number of columns */
 };
 
 /** Exchange rates cache, used by
@@ -102,8 +103,8 @@ static GSList * cached_exchange_rates = NULL;
  * gsb_currency_get_current_exchange
  * gsb_currency_get_current_exchange_fees
  * */
-static gsb_real current_exchange;
-static gsb_real current_exchange_fees;
+static GsbReal current_exchange;
+static GsbReal current_exchange_fees;
 
 
 /*START_EXTERN*/
@@ -145,6 +146,8 @@ GtkWidget *gsb_currency_make_combobox ( gboolean set_name )
 {
     GtkCellRenderer *text_renderer, *flag_renderer;
     GtkWidget *combo_box;
+    gint xpad;
+    gint ypad;
 
     if ( !combobox_currency_store )
         gsb_currency_create_combobox_store ();
@@ -158,7 +161,8 @@ GtkWidget *gsb_currency_make_combobox ( gboolean set_name )
     gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), flag_renderer,
 				    "pixbuf", CURRENCY_COL_FLAG, NULL );
 
-    GTK_CELL_RENDERER(flag_renderer) -> xpad = 3; /* Ugly but how to set it otherwise ?*/
+    gtk_cell_renderer_get_padding ( GTK_CELL_RENDERER ( flag_renderer ), &xpad, &ypad );
+    gtk_cell_renderer_set_padding ( GTK_CELL_RENDERER ( flag_renderer ), 3, ypad );
 
     text_renderer = gtk_cell_renderer_text_new ();
     gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), text_renderer, FALSE);
@@ -248,7 +252,7 @@ gint gsb_currency_get_currency_from_combobox ( GtkWidget *combo_box )
 
 
 /**
- * update the list of the currencies for combobox, wich change all
+ * update the list of the currencies for combobox, which change all
  * the current combobox content
  *
  * \param
@@ -258,7 +262,7 @@ gint gsb_currency_get_currency_from_combobox ( GtkWidget *combo_box )
 gboolean gsb_currency_update_combobox_currency_list ( void )
 {
     GSList *list_tmp;
-    gint handler_id;
+    gulong handler_id;
     gint old_currency_number = -1;
 	gchar* tmpstr;
 
@@ -272,8 +276,8 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
      * try to find why. */
     if ( detail_devise_compte && G_IS_OBJECT ( detail_devise_compte ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (detail_devise_compte), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (detail_devise_compte), "changed-hook" ));
         if ( handler_id > 0 )
         {
             g_signal_handler_block ( (gpointer *) detail_devise_compte,
@@ -284,30 +288,30 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
     }
     if ( combo_devise_totaux_tiers && G_IS_OBJECT ( combo_devise_totaux_tiers ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_tiers), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_tiers), "changed-hook" ));
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_tiers,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_tiers), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_tiers), "changed-hook" ) ));
     }
     if ( combo_devise_totaux_categ  && G_IS_OBJECT ( combo_devise_totaux_categ ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_categ), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_categ), "changed-hook" ));
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_categ,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_categ), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_categ), "changed-hook" ) ));
     }
     if ( combo_devise_totaux_ib  && G_IS_OBJECT ( combo_devise_totaux_ib ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_ib), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_ib), "changed-hook" ));
         if ( handler_id > 0 )
             g_signal_handler_block ( (gpointer *) combo_devise_totaux_ib,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_ib), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_ib), "changed-hook" ) ));
     }
 
     gtk_list_store_clear (GTK_LIST_STORE (combobox_currency_store));
@@ -351,53 +355,54 @@ gboolean gsb_currency_update_combobox_currency_list ( void )
 
     if ( detail_devise_compte && G_IS_OBJECT ( detail_devise_compte ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (detail_devise_compte), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (detail_devise_compte), "changed-hook" ));
+        if ( handler_id > 0 )
         {
             gtk_combo_box_set_active ( GTK_COMBO_BOX (detail_devise_compte),
                             old_currency_number );
             g_signal_handler_unblock ( detail_devise_compte,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (detail_devise_compte), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (detail_devise_compte), "changed-hook" ) ));
         }
     }
     if ( combo_devise_totaux_tiers && G_IS_OBJECT ( combo_devise_totaux_tiers ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_tiers), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_tiers), "changed-hook" ));
         if ( handler_id > 0 )
         {
             gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_tiers),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_tiers,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_tiers), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_tiers), "changed-hook" ) ));
         }
     }
     if ( combo_devise_totaux_categ  && G_IS_OBJECT ( combo_devise_totaux_categ ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_categ), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_categ), "changed-hook" ));
         if ( handler_id > 0 )
         {
             gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_categ),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_categ,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_categ), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_categ), "changed-hook" ) ));
         }
     }
     if ( combo_devise_totaux_ib  && G_IS_OBJECT ( combo_devise_totaux_ib ) )
     {
-        handler_id = (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_ib), "changed-hook" );
+        handler_id = GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_ib), "changed-hook" ));
         if ( handler_id > 0 )
         {
             gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_devise_totaux_ib),
                             old_currency_number );
             g_signal_handler_unblock ( (gpointer *) combo_devise_totaux_ib,
-                            (gulong) g_object_get_data ( G_OBJECT
-                            (combo_devise_totaux_ib), "changed-hook" ) );
+                            GPOINTER_TO_UINT (g_object_get_data ( G_OBJECT
+                            (combo_devise_totaux_ib), "changed-hook" ) ));
         }
     }
 
@@ -492,15 +497,15 @@ void gsb_currency_check_for_change ( gint transaction_number )
 void gsb_currency_exchange_dialog ( gint account_currency_number,
                         gint transaction_currency_number ,
                         gboolean link_currency,
-                        gsb_real exchange_rate,
-                        gsb_real exchange_fees,
+                        GsbReal exchange_rate,
+                        GsbReal exchange_fees,
                         gboolean force )
 {
     GtkWidget *dialog, *label, *hbox, *paddingbox, *table, *widget;
     GtkWidget *entry, *amount_entry, *amount_1_entry, *amount_2_entry, *fees_entry;
     GtkWidget *combobox_1;
     GtkWidget *combobox_2;
-    struct cached_exchange_rate *cache;
+    struct CachedExchangeRate *cache;
     gchar* tmpstr;
     gint row = 0;
     gint result;
@@ -521,10 +526,10 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     }
 
     dialog = gtk_dialog_new_with_buttons ( _("Enter exchange rate"),
-                        GTK_WINDOW ( run.window ),
+                        GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
                         GTK_DIALOG_MODAL,
-                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                        GTK_STOCK_OK, GTK_RESPONSE_OK,
+                        "gtk-cancel", GTK_RESPONSE_CANCEL,
+                        "gtk-ok", GTK_RESPONSE_OK,
                         NULL );
 
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
@@ -534,46 +539,42 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
     tmpstr = g_strdup_printf ( _("Please enter data for the transaction") );
 
     /* Ugly dance to avoid side effects on dialog's vbox. */
-    hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_box_pack_start ( GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ), hbox, FALSE, FALSE, 0 );
     paddingbox = new_paddingbox_with_title ( hbox, TRUE, tmpstr );
     gtk_container_set_border_width ( GTK_CONTAINER(hbox), 6 );
     gtk_container_set_border_width ( GTK_CONTAINER(paddingbox), 6 );
     g_free ( tmpstr );
 
     /* table for layout */
-    table = gtk_table_new ( 2, 5, FALSE );
+    table = gtk_grid_new ();
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
-    gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
 
     /* echange line label */
     label = gtk_label_new ( _("Currencies") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, row, 1, 1);
 
     /* echange line currency 1 */
     combobox_1 = gsb_currency_make_combobox_exchange_dialog (
                         transaction_currency_number,
                         account_currency_number,
                         link_currency );
-    gtk_table_attach ( GTK_TABLE(table), combobox_1, 1, 2, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), combobox_1, 1, row, 1, 1);
 
     /* echange line label */
     label = gtk_label_new ( _("Exchange rate") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.5, 0.0 );
-    gtk_table_attach ( GTK_TABLE(table), label, 2, 3, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.5, 0.0 );
+    gtk_grid_attach (GTK_GRID (table), label, 2, row, 1, 1);
 
     /* echange line currency 2 */
     combobox_2 = gsb_currency_make_combobox_exchange_dialog (
                         transaction_currency_number,
                         account_currency_number,
                         !link_currency );
-    gtk_table_attach ( GTK_TABLE(table), combobox_2, 3, 4, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), combobox_2, 3, row, 1, 1);
     row++;
 
     link_number = gsb_data_currency_link_search ( account_currency_number,
@@ -586,26 +587,22 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
 
     /* amount line */
     label = gtk_label_new ( _("Amounts: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, row, 1, 1);
 
     amount_1_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( amount_1_entry ), TRUE );
-    gtk_table_attach ( GTK_TABLE(table), amount_1_entry, 1, 2, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), amount_1_entry, 1, row, 1, 1);
 
     /* echange line input field */
     entry = gtk_entry_new ();
     gtk_widget_set_size_request ( entry, 100, -1 );
     gtk_entry_set_activates_default ( GTK_ENTRY ( entry ), TRUE );
-    gtk_table_attach ( GTK_TABLE(table), entry, 2, 3, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), entry, 2, row, 1, 1);
 
     amount_2_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( amount_2_entry ), TRUE );
-    gtk_table_attach ( GTK_TABLE(table), amount_2_entry, 3, 4, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), amount_2_entry, 3, row, 1, 1);
 
     /* if amount exist already, fill them here */
     if ( link_currency )
@@ -659,21 +656,18 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
 
     /* exchange fees line label */
     label = gtk_label_new ( _("Exchange fees: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, row, 1, 1);
 
     /* exchange fees line input field */
     fees_entry = gtk_entry_new ();
     gtk_entry_set_activates_default ( GTK_ENTRY ( fees_entry ), TRUE );
-    gtk_table_attach ( GTK_TABLE(table), fees_entry, 1, 2, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), fees_entry, 1, row, 1, 1);
 
     /* exchange fees currency for fees */
     label = gtk_label_new (gsb_data_currency_get_name ( account_currency_number ) );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.0 );
-    gtk_table_attach ( GTK_TABLE(table), label, 2, 3, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.0 );
+    gtk_grid_attach (GTK_GRID (table), label, 2, row, 1, 1);
 
     if ( link_number )
     {
@@ -689,8 +683,7 @@ void gsb_currency_exchange_dialog ( gint account_currency_number,
                         G_CALLBACK ( gsb_currency_checkbutton_link_changed ),
                         &change_link_currency );
 
-        gtk_table_attach ( GTK_TABLE(table), checkbox, 3, 4, row, row+1,
-                        GTK_SHRINK | GTK_FILL, 0, 0, 0 );
+        gtk_grid_attach (GTK_GRID (table), checkbox, 3, row, 1, 1);
     }
 
     /* if the rate or fees exist already, fill them here */
@@ -796,14 +789,14 @@ dialog_return:
  * \return NULL on failure, a pointer to a cached_exchange_rate
  * structure on success.
  */
-struct cached_exchange_rate *gsb_currency_config_get_cached_exchange ( gint currency1_number,
+struct CachedExchangeRate *gsb_currency_config_get_cached_exchange ( gint currency1_number,
                         gint currency2_number )
 {
     GSList * tmp_list = cached_exchange_rates;
 
     while ( tmp_list )
     {
-	struct cached_exchange_rate * tmp;
+	struct CachedExchangeRate * tmp;
 
 	tmp = tmp_list -> data;
 	if ( currency1_number == tmp -> currency1_number && currency2_number == tmp -> currency2_number )
@@ -825,11 +818,11 @@ struct cached_exchange_rate *gsb_currency_config_get_cached_exchange ( gint curr
  */
 void gsb_currency_config_set_cached_exchange ( gint currency1_number,
                         gint currency2_number,
-                        gsb_real change, gsb_real fees )
+                        GsbReal change, GsbReal fees )
 {
-    struct cached_exchange_rate * tmp;
+    struct CachedExchangeRate * tmp;
 
-    tmp = (struct cached_exchange_rate *) g_malloc0(sizeof(struct cached_exchange_rate));
+    tmp = (struct CachedExchangeRate *) g_malloc0(sizeof(struct CachedExchangeRate));
 
     tmp -> currency1_number = currency1_number;
     tmp -> currency2_number = currency2_number;
@@ -872,7 +865,7 @@ gboolean gsb_currency_create_combobox_store ( void )
  * Handler that change the second combobox of a window that ask for
  * change.
  *
- * \param combobox_1 the combobox wich receive the signal
+ * \param combobox_1 the combobox which receive the signal
  * \param combobox_2 the combobox we want to change
  *
  * \return FALSE
@@ -956,7 +949,7 @@ void gsb_currency_init_exchanges ( void )
  * Handler that change the entries and calculate the exchange_rate
  *
  *
- * \param entry_1 the entry wich receive the signal
+ * \param entry_1 the entry which receive the signal
  * \param entry_2 the other entry
  *
  * \return FALSE
@@ -965,7 +958,7 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
                         GtkWidget *entry_2 )
 {
     GtkWidget *entry, *entry_3, *entry_4;
-    gsb_real amount_1, amount_2, taux;
+    GsbReal amount_1, amount_2, taux;
     gboolean link_currency;
     gboolean valide;
 
@@ -989,27 +982,26 @@ gboolean gsb_currency_select_double_amount ( GtkWidget *entry_1,
     if ( valide )
     {
         /* the entry is valid, make it normal */
-        gtk_widget_modify_base ( entry_1, GTK_STATE_NORMAL, NULL );
+        gtk_widget_set_name (entry_1, "form_entry");
     }
     else
     {
         /* the entry is not valid, make it red */
-        gtk_widget_modify_base ( entry_1, GTK_STATE_NORMAL,
-                        gsb_color_get_couleur ( "entry_error_color" ) );
+        gtk_widget_set_name (entry_1, "form_entry_error");
         return FALSE;
     }
+
     valide = gsb_form_widget_get_valide_amout_entry (
                 gtk_entry_get_text ( GTK_ENTRY ( entry_2 ) ) );
     if ( valide )
     {
         /* the entry is valid, make it normal */
-        gtk_widget_modify_base ( entry_2, GTK_STATE_NORMAL, NULL );
+        gtk_widget_set_name (entry_2, "form_entry");
     }
     else
     {
         /* the entry is not valid, make it red */
-        gtk_widget_modify_base ( entry_2, GTK_STATE_NORMAL,
-                        gsb_color_get_couleur ( "entry_error_color" ) );
+        gtk_widget_set_name (entry_2, "form_entry_error");
         return FALSE;
     }
 
@@ -1047,17 +1039,19 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
     GtkTreeIter iter;
     GdkPixbuf *pixbuf;
     gchar *string;
+    gchar *tmp_dir;
+    gint xpad;
+    gint ypad;
 
     combobox_store = gtk_list_store_new ( 3, G_TYPE_INT, GDK_TYPE_PIXBUF,
 						G_TYPE_STRING);
 
-    string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
-                        "flags", G_DIR_SEPARATOR_S,
-                        gsb_data_currency_get_code_iso4217 (
-                        transaction_currency_number ),
-                        ".png", NULL );
-    pixbuf = gdk_pixbuf_new_from_file ( string, NULL );
-    g_free (string);
+    string = g_strconcat ( gsb_data_currency_get_code_iso4217 ( transaction_currency_number ), ".png", NULL );
+
+    tmp_dir = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), "flags", string, NULL );
+    pixbuf = gdk_pixbuf_new_from_file ( tmp_dir, NULL );
+    g_free ( string );
+    g_free ( tmp_dir );
 
     gtk_list_store_append ( GTK_LIST_STORE ( combobox_store ), &iter );
     gtk_list_store_set ( combobox_store, &iter,
@@ -1066,13 +1060,12 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
                     2, gsb_data_currency_get_name ( transaction_currency_number ),
                     -1 );
 
-    string = g_strconcat( gsb_dirs_get_pixmaps_dir ( ), G_DIR_SEPARATOR_S,
-                        "flags", G_DIR_SEPARATOR_S,
-                        gsb_data_currency_get_code_iso4217 (
-                        account_currency_number ),
-                        ".png", NULL );
-    pixbuf = gdk_pixbuf_new_from_file ( string, NULL );
-    g_free (string);
+    string = g_strconcat( gsb_data_currency_get_code_iso4217 ( account_currency_number ), ".png", NULL );
+
+    tmp_dir = g_build_filename ( gsb_dirs_get_pixmaps_dir ( ), "flags", string, NULL );
+    pixbuf = gdk_pixbuf_new_from_file ( tmp_dir, NULL );
+    g_free ( string );
+    g_free ( tmp_dir );
 
     gtk_list_store_append ( GTK_LIST_STORE ( combobox_store ), &iter );
     gtk_list_store_set ( combobox_store, &iter,
@@ -1090,7 +1083,8 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
     gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), flag_renderer,
 				    "pixbuf", 1, NULL );
 
-    GTK_CELL_RENDERER(flag_renderer) -> xpad = 3; /* Ugly but how to set it otherwise ?*/
+    gtk_cell_renderer_get_padding ( GTK_CELL_RENDERER ( flag_renderer ), &xpad, &ypad );
+    gtk_cell_renderer_set_padding ( GTK_CELL_RENDERER ( flag_renderer ), 3, ypad );
 
     text_renderer = gtk_cell_renderer_text_new ();
     gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), text_renderer, FALSE);
@@ -1108,7 +1102,7 @@ GtkWidget *gsb_currency_make_combobox_exchange_dialog ( gint transaction_currenc
  *
  *
 **/
-gsb_real gsb_currency_get_current_exchange ( void )
+GsbReal gsb_currency_get_current_exchange ( void )
 {
     return current_exchange;
 }
@@ -1118,7 +1112,7 @@ gsb_real gsb_currency_get_current_exchange ( void )
  *
  *
 **/
-gboolean gsb_currency_set_current_exchange ( gsb_real exchange )
+gboolean gsb_currency_set_current_exchange ( GsbReal exchange )
 {
     current_exchange.mantissa = exchange.mantissa;
     current_exchange.exponent = exchange.exponent;
@@ -1131,7 +1125,7 @@ gboolean gsb_currency_set_current_exchange ( gsb_real exchange )
  *
  *
 **/
-gsb_real gsb_currency_get_current_exchange_fees ( void )
+GsbReal gsb_currency_get_current_exchange_fees ( void )
 {
     return current_exchange_fees;
 }
@@ -1141,7 +1135,7 @@ gsb_real gsb_currency_get_current_exchange_fees ( void )
  *
  *
 **/
-gboolean gsb_currency_set_current_exchange_fees ( gsb_real fees )
+gboolean gsb_currency_set_current_exchange_fees ( GsbReal fees )
 {
     current_exchange_fees.mantissa = fees.mantissa;
     current_exchange_fees.exponent = fees.exponent;
