@@ -1,6 +1,6 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     Copyright (C)    2000-2008 Cdric Auger (cedric@grisbi.org)            */
+/*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2009-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -35,6 +35,7 @@
 
 /*START_INCLUDE*/
 #include "gsb_data_category.h"
+#include "grisbi_win.h"
 #include "meta_categories.h"
 #include "gsb_category.h"
 #include "gsb_data_account.h"
@@ -48,14 +49,13 @@
 #include "structures.h"
 /*END_INCLUDE*/
 
-/**
- * \struct
- * Describe a category
- */
-typedef struct
+/* struct Describe a category */
+typedef struct _CategoryStruct		CategoryStruct;
+
+struct _CategoryStruct
 {
     /** @name category content */
-    guint category_number;
+    gint category_number;
     gchar *category_name;
     gint category_type;		/**< 0:credit / 1:debit / 2:special (transfert, split...) */
 
@@ -64,38 +64,37 @@ typedef struct
     /** @name gui category list content (not saved) */
     gint category_nb_transactions;
     gint category_nb_direct_transactions;
-    gsb_real category_balance;
-    gsb_real category_direct_balance;
-} struct_category;
+    GsbReal category_balance;
+    GsbReal category_direct_balance;
+};
 
 
-/**
- * \struct
- * Describe a sub-category
- */
-typedef struct
+/* struct Describe a sub-category */
+typedef struct _SubCategoryStruct		SubCategoryStruct;
+
+struct _SubCategoryStruct
 {
     /** @name sub-category content */
-    guint sub_category_number;
+    gint sub_category_number;
     gchar *sub_category_name;
 
-    guint mother_category_number;
+    gint mother_category_number;
 
     /** @name gui sub-category list content (not saved)*/
     gint sub_category_nb_transactions;
-    gsb_real sub_category_balance;
-} struct_sub_category;
+    GsbReal sub_category_balance;
+};
 
 
 
 /*START_STATIC*/
-static void _gsb_data_category_free ( struct_category *category );
-static void _gsb_data_sub_category_free ( struct_sub_category *sub_category );
+static void _gsb_data_category_free ( CategoryStruct *category );
+static void _gsb_data_sub_category_free ( SubCategoryStruct *sub_category );
 static GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
 							GSList *sub_category_list );
-static gint gsb_data_category_get_pointer_from_name_in_glist ( struct_category *category,
+static gint gsb_data_category_get_pointer_from_name_in_glist ( CategoryStruct *category,
 							const gchar *name );
-static gint gsb_data_category_get_pointer_from_sub_name_in_glist ( struct_sub_category *sub_category,
+static gint gsb_data_category_get_pointer_from_sub_name_in_glist ( SubCategoryStruct *sub_category,
 							    const gchar *name );
 static gpointer gsb_data_category_get_structure_in_list ( gint no_category,
                         GSList *list );
@@ -105,23 +104,23 @@ static gint gsb_data_category_new ( const gchar *name );
 static gint gsb_data_category_new_sub_category ( gint category_number,
                         const gchar *name );
 static void gsb_data_category_reset_counters ( void );
-static gint gsb_data_sub_category_compare ( struct_sub_category * a, struct_sub_category * b );
+static gint gsb_data_sub_category_compare ( SubCategoryStruct * a, SubCategoryStruct * b );
 /*END_STATIC*/
 
 /*START_EXTERN*/
 /*END_EXTERN*/
 
 
-/** contains the g_slist of struct_category */
+/** contains the g_slist of CategoryStruct */
 static GSList *category_list = NULL;
 
 /** a pointer to the last category used (to increase the speed) */
-static struct_category *category_buffer;
-static struct_sub_category *sub_category_buffer;
+static CategoryStruct *category_buffer;
+static SubCategoryStruct *sub_category_buffer;
 
 /** a empty category for the list of categories
  * the number of the empty category is 0 */
-static struct_category *empty_category = NULL;
+static CategoryStruct *empty_category = NULL;
 
 
 
@@ -140,7 +139,7 @@ gboolean gsb_data_category_init_variables ( void )
 	    GSList* cat_tmp_list = category_list;
 	    while ( cat_tmp_list )
 	    {
-		struct_category *category;
+		CategoryStruct *category;
 		category = cat_tmp_list -> data;
 		cat_tmp_list = cat_tmp_list -> next;
 		_gsb_data_category_free ( category );
@@ -156,7 +155,7 @@ gboolean gsb_data_category_init_variables ( void )
     /* set an empty name for that empty categ, else every transaction
      * without category will have that name */
     _gsb_data_category_free ( empty_category );
-    empty_category = g_malloc0 ( sizeof ( struct_category ));
+    empty_category = g_malloc0 ( sizeof ( CategoryStruct ));
     empty_category -> category_name = g_strdup(_("No category"));
 
     return FALSE;
@@ -223,7 +222,7 @@ gpointer gsb_data_category_get_structure_in_list ( gint no_category,
 
     while ( tmp )
     {
-	struct_category *category;
+	CategoryStruct *category;
 
 	category = tmp -> data;
 
@@ -251,7 +250,7 @@ gpointer gsb_data_category_get_sub_category_structure ( gint no_category,
                         gint no_sub_category )
 {
     GSList *tmp;
-    struct_category *category;
+    CategoryStruct *category;
 
     /* check empty sub-categ */
     if (!no_sub_category)
@@ -273,7 +272,7 @@ gpointer gsb_data_category_get_sub_category_structure ( gint no_category,
 
     while ( tmp )
     {
-	struct_sub_category *sub_category;
+	SubCategoryStruct *sub_category;
 
 	sub_category = tmp -> data;
 
@@ -311,7 +310,7 @@ GSList *gsb_data_category_get_categories_list ( void )
  * */
 GSList *gsb_data_category_get_sub_category_list ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -332,7 +331,7 @@ GSList *gsb_data_category_get_sub_category_list ( gint no_category )
  * */
 gint gsb_data_category_get_no_category ( gpointer category_ptr )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     if ( !category_ptr )
 	return 0;
@@ -352,7 +351,7 @@ gint gsb_data_category_get_no_category ( gpointer category_ptr )
  * */
 gint gsb_data_category_get_no_sub_category ( gpointer sub_category_ptr )
 {
-    struct_sub_category *sub_category;
+    SubCategoryStruct *sub_category;
 
     /* if sub_category_ptr is NULL, we are on empty sub-category, the number is 0 */
     if ( !sub_category_ptr )
@@ -378,7 +377,7 @@ gint gsb_data_category_max_number ( void )
 
     while ( tmp )
     {
-	struct_category *category;
+	CategoryStruct *category;
 
 	category = tmp -> data;
 
@@ -400,17 +399,19 @@ gint gsb_data_category_max_number ( void )
  * */
 gint gsb_data_category_max_sub_category_number ( gint category_number )
 {
-    struct_category *category;
+    CategoryStruct *category;
     GSList *tmp;
     gint number_tmp = 0;
 
     category = gsb_data_category_get_structure ( category_number );
+    if (!category)
+	return 0;
 
     tmp = category -> sub_category_list;
 
     while ( tmp )
     {
-	struct_sub_category *sub_category;
+	SubCategoryStruct *sub_category;
 
 	sub_category = tmp -> data;
 
@@ -461,9 +462,9 @@ gint gsb_data_category_new ( const gchar *name )
  * */
 gint gsb_data_category_new_with_number ( gint number )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
-    category = g_malloc0 ( sizeof ( struct_category ));
+    category = g_malloc0 ( sizeof ( CategoryStruct ));
     category -> category_number = number;
 
     category_list = g_slist_append ( category_list,
@@ -487,7 +488,8 @@ gint gsb_data_category_new_with_number ( gint number )
  * */
 gboolean gsb_data_category_remove ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
+	GtkWidget *combofix;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -499,13 +501,17 @@ gboolean gsb_data_category_remove ( gint no_category )
 
     _gsb_data_category_free (category);
 
+	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_CATEGORY);
+	if ( combofix )
+		gsb_category_update_combofix ( TRUE );
+
     return TRUE;
 }
 
 /**
  * This function is called to free the memory used by a category structure
  */
-void _gsb_data_category_free ( struct_category *category )
+void _gsb_data_category_free ( CategoryStruct *category )
 {
     if ( ! category )
         return;
@@ -515,7 +521,7 @@ void _gsb_data_category_free ( struct_category *category )
         GSList* sub_tmp_list = category -> sub_category_list;
         while ( sub_tmp_list )
         {
-            struct_sub_category *sub_category;
+            SubCategoryStruct *sub_category;
             sub_category = sub_tmp_list -> data;
             sub_tmp_list = sub_tmp_list -> next;
             _gsb_data_sub_category_free ( sub_category );
@@ -533,7 +539,7 @@ void _gsb_data_category_free ( struct_category *category )
 /**
  * This function is called to free the memory used by a sub category structure
  */
-void _gsb_data_sub_category_free ( struct_sub_category *sub_category )
+void _gsb_data_sub_category_free ( SubCategoryStruct *sub_category )
 {
     if ( ! sub_category )
         return;
@@ -557,8 +563,9 @@ void _gsb_data_sub_category_free ( struct_sub_category *sub_category )
 gboolean gsb_data_category_sub_category_remove ( gint no_category,
                         gint no_sub_category )
 {
-    struct_category *category;
-    struct_sub_category *sub_category;
+    CategoryStruct *category;
+    SubCategoryStruct *sub_category;
+	GtkWidget *combofix;
 
     category = gsb_data_category_get_structure ( no_category );
     sub_category = gsb_data_category_get_sub_category_structure ( no_category,
@@ -574,6 +581,10 @@ gboolean gsb_data_category_sub_category_remove ( gint no_category,
 
     _gsb_data_sub_category_free (sub_category);
 
+	combofix = gsb_form_widget_get_widget (TRANSACTION_FORM_CATEGORY);
+	if ( combofix )
+		gsb_category_update_combofix ( TRUE );
+
     return TRUE;
 }
 
@@ -617,15 +628,15 @@ gint gsb_data_category_new_sub_category ( gint category_number,
 gint gsb_data_category_new_sub_category_with_number ( gint number,
                         gint category_number)
 {
-    struct_category *category;
-    struct_sub_category *sub_category;
+    CategoryStruct *category;
+    SubCategoryStruct *sub_category;
 
     category = gsb_data_category_get_structure ( category_number );
 
     if (!category)
 	return 0;
 
-    sub_category = g_malloc0 ( sizeof (struct_sub_category));
+    sub_category = g_malloc0 ( sizeof (SubCategoryStruct));
     sub_category -> sub_category_number = number;
     sub_category -> mother_category_number = category_number;
 
@@ -674,7 +685,7 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
     if (tab_char[0])
     {
         category_number = gsb_data_category_get_number_by_name ( tab_char[0],
-                            TRUE,
+                            !etat.combofix_force_category,
                             gsb_data_mix_get_amount (
                             transaction_number, is_transaction).mantissa <0 );
 	    gsb_data_mix_set_category_number ( transaction_number,
@@ -685,8 +696,9 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
     if ( tab_char[1] && category_number )
     {
         gsb_data_mix_set_sub_category_number ( transaction_number,
-					        gsb_data_category_get_sub_category_number_by_name (
-                            category_number, tab_char[1], TRUE ),
+					        gsb_data_category_get_sub_category_number_by_name ( category_number,
+																			   tab_char[1],
+																			   !etat.combofix_force_category ),
 					        is_transaction );
     }
     else
@@ -698,7 +710,7 @@ gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
 }
 
 /**
- * return the number of the category wich has the name in param
+ * return the number of the category which has the name in param
  * create it if necessary
  *
  * \param name the name of the category
@@ -720,7 +732,7 @@ gint gsb_data_category_get_number_by_name ( const gchar *name,
 
     if ( list_tmp )
     {
-	struct_category *category;
+	CategoryStruct *category;
 
 	category = list_tmp -> data;
 	category_number = category -> category_number;
@@ -740,7 +752,7 @@ gint gsb_data_category_get_number_by_name ( const gchar *name,
 
 
 /**
- * return the number of the sub-category wich has the name in param
+ * return the number of the sub-category which has the name in param
  * create it if necessary
  *
  * \param category_number the number of the category
@@ -754,7 +766,7 @@ gint gsb_data_category_get_sub_category_number_by_name ( gint category_number,
 							 gboolean create )
 {
     GSList *list_tmp;
-    struct_category *category;
+    CategoryStruct *category;
     gint sub_category_number = 0;
 
     category = gsb_data_category_get_structure ( category_number );
@@ -768,7 +780,7 @@ gint gsb_data_category_get_sub_category_number_by_name ( gint category_number,
 
     if ( list_tmp )
     {
-	struct_sub_category *sub_category;
+	SubCategoryStruct *sub_category;
 
 	sub_category = list_tmp -> data;
 	sub_category_number = sub_category -> sub_category_number;
@@ -797,7 +809,7 @@ gint gsb_data_category_get_sub_category_number_by_name ( gint category_number,
  *
  * \return 0 if it's the same name
  * */
-gint gsb_data_category_get_pointer_from_name_in_glist ( struct_category *category,
+gint gsb_data_category_get_pointer_from_name_in_glist ( CategoryStruct *category,
 							const gchar *name )
 {
     return ( my_strcasecmp ( category -> category_name, name ));
@@ -813,7 +825,7 @@ gint gsb_data_category_get_pointer_from_name_in_glist ( struct_category *categor
  *
  * \return 0 if it's the same name
  * */
-gint gsb_data_category_get_pointer_from_sub_name_in_glist ( struct_sub_category *sub_category,
+gint gsb_data_category_get_pointer_from_sub_name_in_glist ( SubCategoryStruct *sub_category,
 							    const gchar *name )
 {
     if ( !sub_category -> sub_category_name
@@ -839,7 +851,7 @@ gchar *gsb_data_category_get_name ( gint no_category,
 				    gint no_sub_category,
 				    const gchar *return_value_error )
 {
-    struct_category *category;
+    CategoryStruct *category;
     gchar *return_value;
 
     category = gsb_data_category_get_structure ( no_category );
@@ -856,7 +868,7 @@ gchar *gsb_data_category_get_name ( gint no_category,
 
     if ( no_sub_category )
     {
-        struct_sub_category *sub_category;
+        SubCategoryStruct *sub_category;
 
         sub_category = gsb_data_category_get_sub_category_structure ( no_category,
                                           no_sub_category );
@@ -887,7 +899,7 @@ gchar *gsb_data_category_get_name ( gint no_category,
 gboolean gsb_data_category_set_name ( gint no_category,
                         const gchar *name )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -905,7 +917,7 @@ gboolean gsb_data_category_set_name ( gint no_category,
         GtkWidget *combofix;
 
         category -> category_name = my_strdup ( name );
-        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
+        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_CATEGORY);
         if ( combofix )
             gsb_category_update_combofix ( TRUE );
     }
@@ -929,7 +941,7 @@ gchar *gsb_data_category_get_sub_category_name ( gint no_category,
 						 gint no_sub_category,
 						 const gchar *return_value_error )
 {
-    struct_sub_category *sub_category;
+    SubCategoryStruct *sub_category;
 
     sub_category = gsb_data_category_get_sub_category_structure ( no_category,
 								  no_sub_category );
@@ -955,7 +967,7 @@ gboolean gsb_data_category_set_sub_category_name ( gint no_category,
 						   gint no_sub_category,
 						   const gchar *name )
 {
-    struct_sub_category *sub_category;
+    SubCategoryStruct *sub_category;
 
     sub_category = gsb_data_category_get_sub_category_structure ( no_category,
 								  no_sub_category );
@@ -974,7 +986,7 @@ gboolean gsb_data_category_set_sub_category_name ( gint no_category,
         GtkWidget *combofix;
 
         sub_category -> sub_category_name = my_strdup ( name );
-        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
+        combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_CATEGORY);
         if ( combofix )
             gsb_category_update_combofix ( TRUE );
     }
@@ -1012,7 +1024,7 @@ GSList *gsb_data_category_get_name_list ( gboolean set_debit,
 
     while ( tmp_list )
     {
-	struct_category *category;
+	CategoryStruct *category;
 
 	category = tmp_list -> data;
 
@@ -1092,15 +1104,15 @@ void gsb_data_categorie_free_name_list ( GSList *liste )
     gint i;
 
     nbre_list = g_slist_length ( liste );
-
-    for ( i = 0; i < nbre_list -1; i++ )
+    for ( i = 0; i < nbre_list; i++ )
     {
         GSList *tmp_list;
 
-        tmp_list = liste->data;
-        liste = liste->next;
-        g_slist_foreach ( tmp_list, (GFunc) g_free, NULL );
-        g_slist_free ( tmp_list );
+		tmp_list = liste->data;
+		if (i < 2)
+			liste = liste->next;
+
+        g_slist_free_full (tmp_list, (GDestroyNotify) g_free);
     }
 
     g_slist_free ( liste );
@@ -1129,7 +1141,7 @@ GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
 
     while (tmp_list)
     {
-	struct_sub_category *sub_category;
+	SubCategoryStruct *sub_category;
 
 	sub_category = tmp_list -> data;
 
@@ -1156,7 +1168,7 @@ GSList *gsb_data_category_append_sub_category_to_list ( GSList *category_list,
  * */
 gint gsb_data_category_get_type ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1179,7 +1191,7 @@ gint gsb_data_category_get_type ( gint no_category )
 gboolean gsb_data_category_set_type ( gint no_category,
 				      gint category_type )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1200,7 +1212,7 @@ gboolean gsb_data_category_set_type ( gint no_category,
  * */
 gint gsb_data_category_get_nb_transactions ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1223,7 +1235,7 @@ gint gsb_data_category_get_nb_transactions ( gint no_category )
 gint gsb_data_category_get_sub_category_nb_transactions ( gint no_category,
 							  gint no_sub_category )
 {
-    struct_sub_category *sub_category;
+    SubCategoryStruct *sub_category;
 
     sub_category = gsb_data_category_get_sub_category_structure ( no_category,
 								  no_sub_category );
@@ -1245,7 +1257,7 @@ gint gsb_data_category_get_sub_category_nb_transactions ( gint no_category,
  * */
 gint gsb_data_category_get_nb_direct_transactions ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1265,9 +1277,9 @@ gint gsb_data_category_get_nb_direct_transactions ( gint no_category )
  *
  * \return balance of the category or 0 if problem
  * */
-gsb_real gsb_data_category_get_balance ( gint no_category )
+GsbReal gsb_data_category_get_balance ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1286,10 +1298,10 @@ gsb_real gsb_data_category_get_balance ( gint no_category )
  *
  * \return balance of the sub-category or 0 if problem
  * */
-gsb_real gsb_data_category_get_sub_category_balance ( gint no_category,
+GsbReal gsb_data_category_get_sub_category_balance ( gint no_category,
 						      gint no_sub_category )
 {
-    struct_sub_category *sub_category;
+    SubCategoryStruct *sub_category;
 
     sub_category = gsb_data_category_get_sub_category_structure ( no_category,
 								  no_sub_category );
@@ -1307,9 +1319,9 @@ gsb_real gsb_data_category_get_sub_category_balance ( gint no_category,
  *
  * \return balance of the category or 0 if problem
  * */
-gsb_real gsb_data_category_get_direct_balance ( gint no_category )
+GsbReal gsb_data_category_get_direct_balance ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
@@ -1336,7 +1348,7 @@ void gsb_data_category_reset_counters ( void )
 
     while ( list_tmp )
     {
-	struct_category *category;
+	CategoryStruct *category;
 	GSList *sub_list_tmp;
 
 	category = list_tmp -> data;
@@ -1349,7 +1361,7 @@ void gsb_data_category_reset_counters ( void )
 
 	while ( sub_list_tmp )
 	{
-	    struct_sub_category *sub_category;
+	    SubCategoryStruct *sub_category;
 
 	    sub_category = sub_list_tmp -> data;
 
@@ -1380,11 +1392,13 @@ void gsb_data_category_reset_counters ( void )
 void gsb_data_category_update_counters ( void )
 {
     GSList *list_tmp_transactions;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
-    devel_debug ( NULL );
     gsb_data_category_reset_counters ();
 
-    if ( etat.add_archive_in_total_balance )
+    if ( w_etat->metatree_add_archive_in_totals )
         list_tmp_transactions = gsb_data_transaction_get_complete_transactions_list ();
     else
         list_tmp_transactions = gsb_data_transaction_get_transactions_list ();
@@ -1418,8 +1432,8 @@ void gsb_data_category_add_transaction_to_category ( gint transaction_number,
 						     gint category_id,
 						     gint sub_category_id )
 {
-    struct_category *category;
-    struct_sub_category *sub_category;
+    CategoryStruct *category;
+    SubCategoryStruct *sub_category;
 
     /* if the transaction is a transfer or a split transaction, don't take it */
     if (gsb_data_transaction_get_split_of_transaction (transaction_number)
@@ -1431,18 +1445,19 @@ void gsb_data_category_add_transaction_to_category ( gint transaction_number,
     sub_category = gsb_data_category_get_sub_category_structure ( category_id,
 								  sub_category_id );
 
-    /* should not happen, this is if the transaction has a categ wich doesn't exist
+    /* should not happen, this is if the transaction has a categ which doesn't exist
      * we show a debug warning and get without categ */
     if (!category)
     {
-	gchar *tmpstr;
-	tmpstr = g_strdup_printf ( _("The transaction %d has a category n%d and sub-category n%d but they don't exist."),
-				   transaction_number,
-				   category_id,
-				   sub_category_id );
-	warning_debug (tmpstr);
-	g_free (tmpstr);
-	category = empty_category;
+        gchar *tmpstr;
+
+        tmpstr = g_strdup_printf ( "The transaction %d has a category %d and sub-category %d but they don't exist.",
+                       transaction_number,
+                       category_id,
+                       sub_category_id );
+        warning_debug (tmpstr);
+        g_free (tmpstr);
+        category = empty_category;
     }
 
     /* ok, now category is on the structure or on empty_category */
@@ -1490,8 +1505,8 @@ void gsb_data_category_add_transaction_to_category ( gint transaction_number,
  * */
 void gsb_data_category_remove_transaction_from_category ( gint transaction_number )
 {
-    struct_category *category;
-    struct_sub_category *sub_category;
+    CategoryStruct *category;
+    SubCategoryStruct *sub_category;
 
     category = gsb_data_category_get_structure ( gsb_data_transaction_get_category_number (transaction_number));
     sub_category = gsb_data_category_get_sub_category_structure ( gsb_data_transaction_get_category_number (transaction_number),
@@ -1538,7 +1553,7 @@ void gsb_data_category_remove_transaction_from_category ( gint transaction_numbe
  *
  * \return		Same as a <=> b.
  */
-gint gsb_data_sub_category_compare ( struct_sub_category * a, struct_sub_category * b )
+gint gsb_data_sub_category_compare ( SubCategoryStruct * a, SubCategoryStruct * b )
 {
     if ( a != b && a -> sub_category_number == b -> sub_category_number )
     {
@@ -1559,7 +1574,7 @@ gint gsb_data_sub_category_compare ( struct_sub_category * a, struct_sub_categor
  * \return	NULL if no error found.  A string describing any issue
  *		if any.
  */
-gchar * gsb_debug_duplicate_categ_check ()
+gchar * gsb_debug_duplicate_categ_check (void)
 {
     GSList * tmp;
     gint num_duplicate = 0;
@@ -1568,7 +1583,7 @@ gchar * gsb_debug_duplicate_categ_check ()
     tmp = category_list;
     while ( tmp )
     {
-	struct_category * categ = tmp -> data;
+	CategoryStruct * categ = tmp -> data;
 	GSList * tmp_sous_categ = categ -> sub_category_list;
 
 	while ( tmp_sous_categ )
@@ -1584,12 +1599,11 @@ gchar * gsb_debug_duplicate_categ_check ()
 		gchar* tmpstr2 = g_strdup_printf (
 				_("In <i>%s</i>, <i>%s</i> is a duplicate of <i>%s</i>.\n"),
 				categ -> category_name,
-				((struct_sub_category *) tmp_sous_categ -> data) -> sub_category_name,
-				((struct_sub_category *) duplicate -> data) -> sub_category_name );
+				((SubCategoryStruct *) tmp_sous_categ -> data) -> sub_category_name,
+				((SubCategoryStruct *) duplicate -> data) -> sub_category_name );
 		output = g_strconcat ( tmpstr1,
 				       tmpstr2,
 				       NULL );
-		g_free ( tmpstr1 );
 		g_free ( tmpstr2 );
 		num_duplicate ++;
 	    }
@@ -1615,14 +1629,14 @@ gchar * gsb_debug_duplicate_categ_check ()
  *
  * \return	TRUE on success.  FALSE otherwise.
  */
-gboolean gsb_debug_duplicate_categ_fix ()
+gboolean gsb_debug_duplicate_categ_fix (void)
 {
     GSList * tmp;
 
     tmp = category_list;
     while ( tmp )
     {
-	struct_category * categ = tmp -> data;
+	CategoryStruct * categ = tmp -> data;
 	GSList * tmp_sous_categ = categ -> sub_category_list;
 
 	while ( tmp_sous_categ )
@@ -1633,7 +1647,7 @@ gboolean gsb_debug_duplicate_categ_fix ()
 					      (GCompareFunc) gsb_data_sub_category_compare );
 	    if ( duplicate )
 	    {
-		struct_sub_category * duplicate_categ = duplicate -> data;
+		SubCategoryStruct * duplicate_categ = duplicate -> data;
 
 		duplicate_categ -> sub_category_number = gsb_data_category_max_sub_category_number ( categ -> category_number ) + 1;
 	    }
@@ -1662,7 +1676,7 @@ gint gsb_data_category_test_create_category ( gint no_category,
 {
     GSList *list_tmp;
     gint category_number = 0;
-    struct_category *category;
+    CategoryStruct *category;
 
     list_tmp = g_slist_find_custom ( category_list,
                         name,
@@ -1706,11 +1720,13 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
                         const gchar *name )
 {
     GSList *list_tmp;
-    gint sub_category_number = 0;
-    struct_category *category;
-    struct_sub_category *sub_category;
+    CategoryStruct *category;
+    SubCategoryStruct *sub_category;
 
     category = gsb_data_category_get_structure ( no_category );
+    if ( !category )
+        return FALSE;
+
     list_tmp = g_slist_find_custom ( category -> sub_category_list,
                         name,
                         (GCompareFunc) gsb_data_category_get_pointer_from_sub_name_in_glist );
@@ -1723,13 +1739,12 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
                         no_sub_category );
         if ( !sub_category )
         {
-            sub_category_number = gsb_data_category_new_sub_category_with_number (
-                        no_sub_category, no_category );
+            gsb_data_category_new_sub_category_with_number (no_sub_category, no_category);
             gsb_data_category_set_sub_category_name ( no_category, no_sub_category, name );
         }
         else
         {
-            sub_category_number = gsb_data_category_new_sub_category ( no_category, name );
+            gsb_data_category_new_sub_category ( no_category, name );
             gsb_category_update_combofix ( FALSE );
         }
         return TRUE;
@@ -1739,7 +1754,7 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
 
 
 /**
- * retourne le nombre de sous catgories
+ * retourne le nombre de sous catégories
  *
  * \param   no_category
  *
@@ -1747,7 +1762,7 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
  * */
 gint gsb_data_category_get_sub_category_list_length ( gint no_category )
 {
-    struct_category *category;
+    CategoryStruct *category;
 
     category = gsb_data_category_get_structure ( no_category );
 
