@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -39,6 +39,7 @@
 #include "bet_data.h"
 #include "classement_echeances.h"
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_budget.h"
@@ -67,15 +68,15 @@ typedef struct
     gint transaction_number;
     gchar *transaction_id;              /**< filled by ofx */
     gint account_number;
-    gsb_real transaction_amount;
+    GsbReal transaction_amount;
     gint party_number;                  /* payee in transaction */
     gchar *notes;
-    gint marked_transaction;            /**<  OPERATION_NORMALE=nothing, OPERATION_POINTEE=P, OPERATION_TELERAPPROCHEE=T, OPERATION_RAPPROCHEE=R */
+    gint marked_transaction;            /**<  OPERATION_NORMALE=nothing, OPERATION_POINTEE=P, OPERATION_TELEPOINTEE=T, OPERATION_RAPPROCHEE=R */
     gint archive_number;                /**< if it's an archived transaction, contains the number of the archive */
     gshort automatic_transaction;       /**< 0=manual, 1=automatic (scheduled transaction) */
     gint reconcile_number;              /**< the number of reconciliation, carreful : can be filled without marked_transaction=OPERATION_RAPPROCHEE sometimes,
                                              it happen if the user did ctrl R to un-R the transaction, we keep reconcile_number because most of them
-                                             will re-R after the change, and that value will help the user to find wich statement it belong.
+                                             will re-R after the change, and that value will help the user to find which statement it belong.
                                              o always check marked_transaction before checking reconcile_number here */
     guint financial_year_number;
     gchar *voucher;
@@ -88,8 +89,8 @@ typedef struct
     /** @name currency stuff */
     gint currency_number;
     gint change_between_account_and_transaction;    /**< if 1 : 1 account_currency = (exchange_rate * amount) transaction_currency */
-    gsb_real exchange_rate;
-    gsb_real exchange_fees;
+    GsbReal exchange_rate;
+    GsbReal exchange_fees;
 
     /** @name category stuff */
     gint category_number;
@@ -414,18 +415,18 @@ gboolean gsb_data_transaction_set_transaction_id ( gint transaction_number,
 {
     struct_transaction *transaction;
 
-    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
+    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
 
     if ( !transaction )
-	return FALSE;
+        return FALSE;
 
-    if ( transaction -> transaction_id )
-        g_free ( transaction -> transaction_id );
+    g_free ( transaction -> transaction_id );
 
-    if (transaction_id)
-	transaction -> transaction_id = my_strdup (transaction_id);
+    if ( transaction_id )
+        transaction -> transaction_id = my_strdup ( transaction_id );
     else
-    	transaction -> transaction_id = NULL;
+        transaction -> transaction_id = NULL;
+
     return TRUE;
 }
 
@@ -537,7 +538,6 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
 
     if (transaction -> date)
         g_date_free (transaction -> date);
-
     transaction -> date = gsb_date_copy (date);
 
     /* if the transaction is a split, change all the children */
@@ -555,7 +555,6 @@ gboolean gsb_data_transaction_set_date ( gint transaction_number,
 
 	    if (transaction -> date)
             g_date_free (transaction -> date);
-
 	    transaction -> date = gsb_date_copy (date);
 
         /* si l'opération fille est un transfert on regarde si la contre opération est rapprochée
@@ -621,8 +620,7 @@ gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
 	return FALSE;
 
     if (transaction ->  value_date)
-	g_date_free (transaction ->  value_date);
-
+        g_date_free (transaction ->  value_date);
     transaction ->  value_date = gsb_date_copy (date);
 
     /* if the transaction is a split, change all the children */
@@ -639,8 +637,7 @@ gboolean gsb_data_transaction_set_value_date ( gint transaction_number,
 	    transaction = tmp_list -> data;
 
 	    if (transaction ->  value_date)
-		g_date_free (transaction -> value_date);
-
+            g_date_free (transaction -> value_date);
 	    transaction -> value_date = gsb_date_copy (date);
 
 	    tmp_list = tmp_list -> next;
@@ -683,7 +680,7 @@ const GDate *gsb_data_transaction_get_value_date_or_date ( gint transaction_numb
  *
  * \return the amount of the transaction
  * */
-gsb_real gsb_data_transaction_get_amount ( gint transaction_number )
+GsbReal gsb_data_transaction_get_amount ( gint transaction_number )
 {
     struct_transaction *transaction;
 
@@ -704,7 +701,7 @@ gsb_real gsb_data_transaction_get_amount ( gint transaction_number )
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_amount ( gint transaction_number,
-                        gsb_real amount )
+                        GsbReal amount )
 {
     struct_transaction *transaction;
 
@@ -735,7 +732,7 @@ gboolean gsb_data_transaction_set_amount ( gint transaction_number,
  *
  * \return the amount of the transaction
  * */
-gsb_real gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
+GsbReal gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
                         gint return_exponent )
 {
     struct_transaction *transaction;
@@ -763,12 +760,12 @@ gsb_real gsb_data_transaction_get_adjusted_amount ( gint transaction_number,
  *
  * \return the amount of the transaction
  * */
-gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction_number,
+GsbReal gsb_data_transaction_get_adjusted_amount_for_currency ( gint transaction_number,
                         gint return_currency_number,
                         gint return_exponent )
 {
     struct_transaction *transaction;
-    gsb_real amount = null_real;
+    GsbReal amount = null_real;
     gint link_number;
 
     if (return_exponent == -1)
@@ -816,8 +813,8 @@ gsb_real gsb_data_transaction_get_adjusted_amount_for_currency ( gint transactio
     }
     else if ( return_currency_number > 0 && transaction -> currency_number > 0 )
     {
-        gsb_real current_exchange;
-        gsb_real current_exchange_fees;
+        GsbReal current_exchange;
+        GsbReal current_exchange_fees;
 
         gsb_currency_exchange_dialog ( return_currency_number,
                         transaction -> currency_number,
@@ -987,7 +984,7 @@ gboolean gsb_data_transaction_set_change_between ( gint transaction_number,
  *
  * \return the exchange_rate of the transaction
  * */
-gsb_real gsb_data_transaction_get_exchange_rate ( gint transaction_number )
+GsbReal gsb_data_transaction_get_exchange_rate ( gint transaction_number )
 {
     struct_transaction *transaction;
 
@@ -1010,7 +1007,7 @@ gsb_real gsb_data_transaction_get_exchange_rate ( gint transaction_number )
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
-                        gsb_real rate )
+                        GsbReal rate )
 {
     struct_transaction *transaction;
 
@@ -1050,7 +1047,7 @@ gboolean gsb_data_transaction_set_exchange_rate ( gint transaction_number,
  *
  * \return the exchange_fees of the transaction
  * */
-gsb_real gsb_data_transaction_get_exchange_fees ( gint transaction_number )
+GsbReal gsb_data_transaction_get_exchange_fees ( gint transaction_number )
 {
     struct_transaction *transaction;
 
@@ -1073,7 +1070,7 @@ gsb_real gsb_data_transaction_get_exchange_fees ( gint transaction_number )
  * \return TRUE if ok
  * */
 gboolean gsb_data_transaction_set_exchange_fees ( gint transaction_number,
-                        gsb_real rate )
+                        GsbReal rate )
 {
     struct_transaction *transaction;
 
@@ -1331,19 +1328,11 @@ gboolean gsb_data_transaction_set_notes ( gint transaction_number,
     struct_transaction *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
-
     if ( !transaction )
-	return FALSE;
+        return FALSE;
 
-    if ( transaction -> notes )
-        g_free ( transaction -> notes );
-
-    if ( notes
-	 &&
-	 strlen (notes))
-	transaction -> notes = my_strdup (notes);
-    else
-	transaction -> notes = NULL;
+    g_free ( transaction -> notes );
+    transaction -> notes = my_strdup ( notes );
 
     return TRUE;
 }
@@ -1446,19 +1435,11 @@ gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_n
     struct_transaction *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
-
     if ( !transaction )
-	return FALSE;
+        return FALSE;
 
-    if ( transaction -> method_of_payment_content )
-        g_free ( transaction -> method_of_payment_content );
-
-    if ( method_of_payment_content
-	 &&
-	 strlen (method_of_payment_content))
-	transaction -> method_of_payment_content = my_strdup (method_of_payment_content);
-    else
-	transaction -> method_of_payment_content = NULL;
+    g_free ( transaction -> method_of_payment_content );
+    transaction -> method_of_payment_content = my_strdup ( method_of_payment_content );
 
     return TRUE;
 }
@@ -1470,7 +1451,7 @@ gboolean gsb_data_transaction_set_method_of_payment_content ( gint transaction_n
  *
  * \param transaction_number the number of the transaction
  *
- * \return the marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELERAPPROCHEE, OPERATION_RAPPROCHEE
+ * \return the marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELEPOINTEE, OPERATION_RAPPROCHEE
  * */
 gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
 {
@@ -1490,7 +1471,7 @@ gint gsb_data_transaction_get_marked_transaction ( gint transaction_number )
  * if the transaction has some children, they change too
  *
  * \param transaction_number
- * \param marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELERAPPROCHEE, OPERATION_RAPPROCHEE
+ * \param marked_transaction : OPERATION_NORMALE, OPERATION_POINTEE, OPERATION_TELEPOINTEE, OPERATION_RAPPROCHEE
  *
  * \return TRUE if ok
  * */
@@ -1831,21 +1812,16 @@ gboolean gsb_data_transaction_set_voucher ( gint transaction_number,
 {
     struct_transaction *transaction;
 
-    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
-
+    transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number );
     if ( !transaction )
-	return FALSE;
+        return FALSE;
 
+    g_free ( transaction -> voucher );
 
-    if ( transaction -> voucher )
-        g_free ( transaction -> voucher );
-
-    if ( voucher
-	 &&
-	 strlen (voucher))
-	transaction -> voucher = my_strdup (voucher);
+    if ( voucher && strlen (voucher) )
+        transaction -> voucher = my_strdup ( voucher );
     else
-	transaction -> voucher = g_strdup("");
+        transaction -> voucher = g_strdup ("");
 
     return TRUE;
 }
@@ -1887,19 +1863,11 @@ gboolean gsb_data_transaction_set_bank_references ( gint transaction_number,
     struct_transaction *transaction;
 
     transaction = gsb_data_transaction_get_transaction_by_no ( transaction_number);
-
     if ( !transaction )
-	return FALSE;
+        return FALSE;
 
-    if ( transaction -> bank_references )
-        g_free ( transaction -> bank_references );
-
-    if ( bank_references
-	 &&
-	 strlen (bank_references))
-	transaction -> bank_references = my_strdup (bank_references);
-    else
-	transaction -> bank_references = NULL;
+    g_free ( transaction -> bank_references );
+    transaction -> bank_references = my_strdup ( bank_references );
 
     return TRUE;
 }
@@ -2209,22 +2177,22 @@ static void gsb_data_transaction_free ( struct_transaction *transaction)
 {
     if ( ! transaction )
         return;
+
     gsb_data_account_set_balances_are_dirty ( transaction -> account_number );
-    if ( transaction -> transaction_id )
-        g_free ( transaction -> transaction_id );
-    if ( transaction -> notes )
-        g_free ( transaction -> notes );
-    if ( transaction -> voucher )
-        g_free ( transaction -> voucher );
-    if ( transaction -> bank_references )
-        g_free ( transaction -> bank_references );
+
+    g_free ( transaction -> transaction_id );
+    g_free ( transaction -> notes );
+    g_free ( transaction -> voucher );
+    g_free ( transaction -> bank_references );
+    g_free ( transaction -> method_of_payment_content );
+
     if ( transaction -> date )
         g_date_free ( transaction -> date );
     if ( transaction -> value_date )
         g_date_free ( transaction -> value_date );
-    if ( transaction -> method_of_payment_content )
-        g_free ( transaction -> method_of_payment_content );
+
     g_free ( transaction );
+
     transaction_buffer[0] = NULL;
     transaction_buffer[1] = NULL;
 }
@@ -2594,13 +2562,16 @@ gint gsb_data_transaction_check_content_payment ( gint payment_number,
 GSList *gsb_data_transaction_get_metatree_transactions_list ( void )
 {
     GSList *list_tmp;
+	GrisbiWinEtat *w_etat;
 
-    if ( etat.add_archive_in_total_balance )
+	w_etat = grisbi_win_get_w_etat ();
+
+    if ( w_etat->metatree_add_archive_in_totals )
         list_tmp = g_slist_copy ( complete_transactions_list );
     else
         list_tmp = g_slist_copy ( transactions_list );
 
-    switch ( etat.metatree_sort_transactions )
+    switch ( w_etat->metatree_sort_transactions )
     {
         case 1 :
         list_tmp = g_slist_sort (list_tmp,
@@ -2644,7 +2615,7 @@ const gchar *gsb_data_transaction_get_id ( gint transaction_number )
  *
  *
  * */
-gsb_real gsb_data_transaction_get_last_transaction_with_div_sub_div (
+GsbReal gsb_data_transaction_get_last_transaction_with_div_sub_div (
                         gint account_number,
                         gint div_number,
                         gint sub_div_nb,
