@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -61,7 +61,6 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *form_button_recover_split;
 /*END_EXTERN*/
 
 
@@ -111,8 +110,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
                ||
                (GTK_IS_COMBOFIX (element -> element_widget)
                 &&
-                !gsb_form_widget_check_empty ( GTK_COMBOFIX (
-                element -> element_widget ) -> entry ) ) ) )
+                !gsb_form_widget_check_empty (element->element_widget) ) ) )
             return TRUE;
 
         tmp_list = tmp_list -> next;
@@ -173,7 +171,10 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
         &&
         gsb_data_transaction_get_split_of_transaction (transaction_number))
         {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON ( form_button_recover_split ),
+			GtkWidget *form_button_recover_split;
+
+			form_button_recover_split = gsb_form_get_recover_split_button ();
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON ( form_button_recover_split ),
                         conf.automatic_recover_splits );
             gtk_widget_show ( form_button_recover_split );
         }
@@ -208,7 +209,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
             gsb_payment_method_create_combo_list ( widget, GSB_PAYMENT_CREDIT,
                         account_number, 0, FALSE );
 
-        if ( GTK_WIDGET_VISIBLE (widget))
+        if ( gtk_widget_get_visible (widget))
         {
             gint tmp_account;
 
@@ -398,7 +399,7 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
                 GSList *list_payees;
                 GSList *list_tmp;
 
-                list_payees = gsb_data_report_get_payee_numbers ( report_number );
+                list_payees = gsb_data_report_get_payee_numbers_list ( report_number );
                 list_tmp = list_payees;
                 while ( list_tmp )
                 {
@@ -411,7 +412,7 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
             else
                 /* the report was not found, set -1 */
                 parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
-                g_strfreev ( tab_char );
+			g_strfreev ( tab_char );
         }
     }
     else
@@ -442,7 +443,7 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
     GDate *contra_value_date = NULL;
     const gchar *contra_transaction_content = NULL;
     gint contra_payment_number = 0;
-    gint contra_transaction_number;
+    gint contra_transaction_number = 0;
     gint contra_mother_number = 0;
     gint contra_marked_transaction = 0;
     GtkWidget *contra_payment_button;
@@ -563,7 +564,7 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
         contra_payment_button = gsb_form_widget_get_widget ( TRANSACTION_FORM_CONTRA );
         if ( contra_payment_button
          &&
-         GTK_WIDGET_VISIBLE ( contra_payment_button ) )
+         gtk_widget_get_visible ( contra_payment_button ) )
         gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
                         gsb_payment_method_get_selected_number ( contra_payment_button ) );
     }
