@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -39,8 +39,7 @@
 /*START_INCLUDE*/
 #include "gsb_reconcile.h"
 #include "dialog.h"
-#include "fenetre_principale.h"
-#include "gsb_color.h"
+#include "grisbi_win.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_data_account.h"
 #include "gsb_data_reconcile.h"
@@ -50,6 +49,7 @@
 #include "gsb_form_widget.h"
 #include "gsb_real.h"
 #include "gsb_reconcile_list.h"
+#include "gsb_rgba.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_transactions_list.h"
 #include "menu.h"
@@ -58,6 +58,8 @@
 #include "traitement_variables.h"
 #include "transaction_list.h"
 #include "transaction_list_sort.h"
+#include "utils.h"
+#include "utils_buttons.h"
 #include "utils_dates.h"
 #include "utils_real.h"
 #include "utils_str.h"
@@ -77,7 +79,6 @@ static gchar *gsb_reconcile_build_label ( int reconcile_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *label_last_statement;
 extern GtkWidget * reconcile_panel;
 /*END_EXTERN*/
 
@@ -105,6 +106,44 @@ static gint reconcile_save_account_display;
 /* backup the number of the last transaction converted into planned transaction during the reconciliation */
 static gint reconcile_save_last_scheduled_convert = 0;
 
+/**
+ * return the date max of transactions ready to reconcile
+ *
+ * \param account_number the number of the current account
+ *
+ * \return the date max of the  transactions
+ **/
+static const GDate *gsb_reconcile_get_pointed_transactions_max_date (gint account_number)
+{
+    GSList *list_tmp;
+    const GDate *max_date = NULL;
+
+    list_tmp = gsb_data_transaction_get_transactions_list ();
+
+    while (list_tmp)
+    {
+        gint transaction_number;
+        const GDate *transaction_date;
+
+        transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
+        if (gsb_data_transaction_get_account_number (transaction_number) == account_number
+			&&
+			(gsb_data_transaction_get_marked_transaction (transaction_number) == OPERATION_POINTEE
+			 ||
+			 gsb_data_transaction_get_marked_transaction (transaction_number) == OPERATION_TELEPOINTEE))
+		{
+            transaction_date = gsb_data_transaction_get_date (transaction_number);
+            //~ printf("transaction_date: %s\n", gsb_format_gdate (transaction_date));
+            if (max_date == NULL || g_date_compare (transaction_date, max_date) > 0)
+			{
+                max_date = transaction_date;
+                //~ printf("max_date: %s\n", gsb_format_gdate (max_date));
+            }
+        }
+        list_tmp = list_tmp -> next;
+    }
+    return max_date;
+}
 
 /**
  * Create a vbox that contains all controls used to display
@@ -115,64 +154,75 @@ static gint reconcile_save_last_scheduled_convert = 0;
 GtkWidget *gsb_reconcile_create_box ( void )
 {
     GtkWidget *frame, *label, *table, *vbox, *hbox, *button, *separator;
+	GtkWidget *sw;
 
     frame = gtk_frame_new ( NULL );
-    vbox = gtk_vbox_new ( FALSE, 3 );
-    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 3 );
-    gtk_container_add ( GTK_CONTAINER ( frame ), vbox );
+	sw = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+									GTK_POLICY_AUTOMATIC,
+									GTK_POLICY_NEVER);
+	gtk_container_add (GTK_CONTAINER (frame), sw);
+
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, 0 );
+    gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), MARGIN_BOX);
+    gtk_container_add (GTK_CONTAINER (sw), vbox);
 
     /* the title of the frame */
     label = gtk_label_new ( NULL );
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
-    gtk_misc_set_alignment ( GTK_MISC (label), 0.0, 0.0 );
+    utils_labels_set_alignment ( GTK_LABEL (label), 0.0, 0.0 );
     gtk_frame_set_label_widget ( GTK_FRAME(frame), label);
 
     /* number of reconcile */
-    hbox = gtk_hbox_new ( FALSE, 5 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
     gtk_box_pack_start ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new ( _("Reconciliation reference: ") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0);
 
     reconcile_number_entry = gtk_entry_new ();
+	gtk_entry_set_width_chars (GTK_ENTRY (reconcile_number_entry), 12);
+	gtk_widget_set_hexpand (reconcile_number_entry, TRUE);
     gtk_widget_set_tooltip_text ( GTK_WIDGET (reconcile_number_entry),
-                            _("If reconciliation reference ends in a digit, it is "
-                            "automatically incremented at each reconciliation.\n"
-                            "You can let it empty if you don't want to keep a trace of "
-                            "the reconciliation.") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), reconcile_number_entry, TRUE, TRUE, 0);
+								 _("If reconciliation reference ends in a digit, it is "
+								   "automatically incremented at each reconciliation.\n"
+								   "You can let it empty if you don't want to keep a trace of "
+								   "the reconciliation.") );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), reconcile_number_entry, FALSE, FALSE, 0);
 
-    separator = gtk_hseparator_new();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
 
     /* under the reconcile number, we have a table */
-    table = gtk_table_new ( 3, 5, FALSE );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 3 );
+    table = gtk_grid_new ();
+    gtk_grid_set_column_spacing (GTK_GRID (table), MARGIN_BOX);
+	gtk_grid_set_row_spacing (GTK_GRID (table), MARGIN_BOX);
     gtk_box_pack_start ( GTK_BOX ( vbox ), table, FALSE, FALSE, 0);
 
-    separator = gtk_hseparator_new();
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), separator, 0, 3, 1, 2 );
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
+    gtk_grid_attach (GTK_GRID (table), separator, 0, 1, 3, 1 );
 
-    separator = gtk_hseparator_new();
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), separator, 0, 3, 3, 4 );
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
+    gtk_grid_attach (GTK_GRID (table), separator, 0, 3, 3, 1 );
 
-    separator = gtk_vseparator_new ();
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), separator, 1, 2, 0, 5 );
+    separator = gtk_separator_new ( GTK_ORIENTATION_VERTICAL );
+	gtk_widget_set_margin_start (separator, MARGIN_BOX);
+	gtk_widget_set_margin_end (separator, MARGIN_BOX);
+    gtk_grid_attach (GTK_GRID (table), separator, 1, 0, 1, 5 );
 
     label = gtk_label_new ( _("Date") );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, 0, 1);
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     label = gtk_label_new ( _("Balance") );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 2, 3, 0, 1);
+    gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
 
     reconcile_last_date_label = gtk_label_new ( NULL );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_last_date_label,
-				0, 1, 2, 3 );
+    gtk_grid_attach (GTK_GRID (table), reconcile_last_date_label, 0, 2, 1, 1 );
 
-    /* set the old balance,
-     * an entry the first time, will be unsensitive after */
+    /* set the old balance, an entry the first time, will be unsensitive after */
     reconcile_initial_balance_entry = gtk_entry_new ( );
-    gtk_widget_set_size_request ( reconcile_initial_balance_entry, 50, -1 );
+	gtk_entry_set_width_chars (GTK_ENTRY (reconcile_initial_balance_entry), 13);
+	gtk_widget_set_hexpand (reconcile_initial_balance_entry, TRUE);
     g_signal_connect ( G_OBJECT ( reconcile_initial_balance_entry ),
                         "changed",
 		                G_CALLBACK (gsb_reconcile_update_amounts),
@@ -181,18 +231,18 @@ GtkWidget *gsb_reconcile_create_box ( void )
 			            "focus-out-event",
                         G_CALLBACK ( gsb_reconcile_entry_lose_focus ),
                         NULL );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_initial_balance_entry,
-				2, 3, 2, 3 );
+    gtk_grid_attach (GTK_GRID (table), reconcile_initial_balance_entry, 2, 2, 1, 1 );
 
     /* make the new date entry */
     reconcile_new_date_entry = gsb_calendar_entry_new (TRUE);
-    gtk_widget_set_size_request ( reconcile_new_date_entry, 50, -1 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_new_date_entry,
-				0, 1, 4, 5 );
+    gtk_entry_set_width_chars (GTK_ENTRY (reconcile_new_date_entry), 13);
+	gtk_widget_set_hexpand (reconcile_new_date_entry, TRUE);
+    gtk_grid_attach (GTK_GRID (table), reconcile_new_date_entry, 0, 4, 1, 1 );
 
     /* set the new balance */
     reconcile_final_balance_entry = gtk_entry_new ();
-    gtk_widget_set_size_request ( reconcile_final_balance_entry, 50, -1 );
+	gtk_entry_set_width_chars (GTK_ENTRY (reconcile_final_balance_entry), 13);
+	gtk_widget_set_hexpand (reconcile_final_balance_entry, TRUE);
     g_signal_connect ( G_OBJECT ( reconcile_final_balance_entry ),
                         "changed",
 		                G_CALLBACK (gsb_reconcile_update_amounts),
@@ -201,58 +251,59 @@ GtkWidget *gsb_reconcile_create_box ( void )
 			            "focus-out-event",
                         G_CALLBACK ( gsb_reconcile_entry_lose_focus ),
                         NULL );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_final_balance_entry,
-				2, 3, 4, 5 );
-
-    separator = gtk_hseparator_new();
-    gtk_box_pack_start ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
-
+    gtk_grid_attach (GTK_GRID (table), reconcile_final_balance_entry, 2, 4, 1, 1 );
 
     /* 2nd table under that, with the balances labels */
-    table = gtk_table_new ( 5, 2, FALSE );
-    gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
+    table = gtk_grid_new ();
+    gtk_grid_set_row_spacing (GTK_GRID (table), 5);
+	gtk_grid_set_column_homogeneous (GTK_GRID (table),TRUE);
     gtk_box_pack_start ( GTK_BOX ( vbox ), table, FALSE, FALSE, 0);
 
     label = gtk_label_new ( _("Initial balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, 0, 1);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     reconcile_initial_balance_label = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC ( reconcile_initial_balance_label ), 1, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_initial_balance_label, 1, 2, 0, 1);
+    utils_labels_set_alignment ( GTK_LABEL ( reconcile_initial_balance_label ), 1, 0.5 );
+    gtk_widget_set_hexpand (reconcile_initial_balance_label, TRUE);
+    gtk_widget_set_halign (reconcile_initial_balance_label, GTK_ALIGN_END);
+    gtk_grid_attach (GTK_GRID (table), reconcile_initial_balance_label, 1, 0, 1, 1);
 
     label = gtk_label_new ( _("Final balance: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, 1, 2);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
     reconcile_final_balance_label = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC ( reconcile_final_balance_label ), 1, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_final_balance_label, 1, 2, 1, 2);
+    utils_labels_set_alignment ( GTK_LABEL ( reconcile_final_balance_label ), 1, 0.5 );
+    gtk_widget_set_halign (reconcile_final_balance_label, GTK_ALIGN_END);
+    gtk_grid_attach (GTK_GRID (table), reconcile_final_balance_label, 1, 1, 1, 1);
 
     label = gtk_label_new ( _("Checking: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, 2, 3);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
 
     reconcile_marked_balance_label = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC ( reconcile_marked_balance_label ), 1, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_marked_balance_label, 1, 2, 2, 3);
+    utils_labels_set_alignment ( GTK_LABEL ( reconcile_marked_balance_label ), 1, 0.5 );
+    gtk_widget_set_halign (reconcile_marked_balance_label, GTK_ALIGN_END);
+    gtk_grid_attach (GTK_GRID (table), reconcile_marked_balance_label, 1, 2, 1, 1);
 
-    separator = gtk_hseparator_new();
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), separator, 0, 2, 3, 4);
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
+    gtk_grid_attach (GTK_GRID (table), separator, 0, 3, 2, 1);
 
     label = gtk_label_new ( _("Variance: ") );
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), label, 0, 1, 4, 5);
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 4, 1, 1);
 
     reconcile_variation_balance_label = gtk_label_new ( NULL );
-    gtk_misc_set_alignment ( GTK_MISC ( reconcile_variation_balance_label ), 1, 0.5 );
-    gtk_table_attach_defaults ( GTK_TABLE ( table ), reconcile_variation_balance_label, 1, 2, 4, 5);
+    utils_labels_set_alignment ( GTK_LABEL ( reconcile_variation_balance_label ), 1, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), reconcile_variation_balance_label, 1, 4, 1, 1);
 
     /* set the button to sort with the method of paymen */
-    separator = gtk_hseparator_new();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
 
-    hbox = gtk_hbox_new ( TRUE, 3 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_set_homogeneous ( GTK_BOX ( hbox ), TRUE );
     gtk_box_pack_start ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 0);
 
     reconcile_sort_list_button = gtk_check_button_new_with_label (_("Sort by method of payment"));
@@ -262,22 +313,23 @@ GtkWidget *gsb_reconcile_create_box ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), reconcile_sort_list_button, FALSE, FALSE, 0);
 
     /* make the buttons */
-    hbox = gtk_hbox_new ( TRUE, 3 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_set_homogeneous ( GTK_BOX ( hbox ), TRUE );
     gtk_box_pack_end ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 0);
 
-    button = gtk_button_new_from_stock ( GTK_STOCK_CANCEL );
+    button = utils_buttons_button_new_from_stock ("gtk-cancel", _("Cancel"));
     gtk_button_set_relief ( GTK_BUTTON ( button), GTK_RELIEF_NONE);
     g_signal_connect ( G_OBJECT (button), "clicked",
 		       G_CALLBACK (gsb_reconcile_cancel), NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0);
 
-    reconcile_ok_button = gtk_button_new_from_stock ( GTK_STOCK_OK );
+    reconcile_ok_button = utils_buttons_button_new_from_stock ("gtk-ok", _("Validate"));
     gtk_button_set_relief ( GTK_BUTTON ( reconcile_ok_button), GTK_RELIEF_NONE);
     g_signal_connect ( G_OBJECT ( reconcile_ok_button ), "clicked",
 		       G_CALLBACK (gsb_reconcile_finish_reconciliation), NULL );
     gtk_box_pack_start ( GTK_BOX ( hbox ), reconcile_ok_button, FALSE, FALSE, 0);
 
-    separator = gtk_hseparator_new();
+    separator = gtk_separator_new ( GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_end ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
 
     gtk_widget_show_all ( frame );
@@ -307,7 +359,7 @@ gchar *gsb_reconcile_build_label ( int reconcile_number )
     gchar *new_label;
     gchar format[6] = "%s%0d";
     int __reconcile_number;
-    int __size;
+    size_t __size;
     int __expand;
 
     /* old_label = NAME + NUMBER */
@@ -423,18 +475,20 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
         {
             GDate *today;
             gchar *string ;
+			GrisbiWinEtat *w_etat;
 
+			w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
             string = gsb_format_gdate ( date );
-            gtk_label_set_text ( GTK_LABEL ( reconcile_last_date_label ),
-                    string);
-            gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_last_date_label ),
-                    FALSE );
+            gtk_label_set_text ( GTK_LABEL ( reconcile_last_date_label ), string);
+            gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_last_date_label ), FALSE );
+			gtk_widget_set_name (reconcile_last_date_label, "reconcile_old_entry_insensitive");
+
             g_free (string);
             g_date_add_months ( date, 1 );
 
-            /* if etat.reconcile_end_date or the new date is after today, set today */
+            /* if w_etat->reconcile_end_date or the new date is after today, set today */
             today = gdate_today();
-            if ( etat.reconcile_end_date || g_date_compare ( date, today) > 0 )
+            if ( w_etat->reconcile_end_date || g_date_compare ( date, today) > 0 )
             {
                 g_date_free (date);
                 date = gdate_today();
@@ -446,8 +500,8 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
             tmpstr = utils_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
             gtk_entry_set_text ( GTK_ENTRY ( reconcile_initial_balance_entry ), tmpstr);
             g_free ( tmpstr );
-            gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_initial_balance_entry ),
-                    FALSE );
+			gtk_widget_set_name (reconcile_initial_balance_entry, "reconcile_old_entry_insensitive");
+            gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_initial_balance_entry ), FALSE );
         }
         else
         {
@@ -460,6 +514,7 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
             tmpstr = utils_real_get_string ( gsb_data_account_get_init_balance (account_number, -1));
             gtk_entry_set_text ( GTK_ENTRY ( reconcile_initial_balance_entry ), tmpstr);
             g_free ( tmpstr );
+			gtk_widget_set_name (reconcile_initial_balance_entry, "reconcile_old_entry");
             gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_initial_balance_entry ), TRUE );
         }
     }
@@ -536,12 +591,14 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
 gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 					    gpointer null )
 {
+	GtkWidget *label_last_statement;
     GSList *list_tmp_transactions;
     GDate *date;
     const GDate *initial_date;
+	const GDate *transactions_max_date;
     gint account_number;
     gint reconcile_number;
-    gsb_real real;
+    GsbReal real;
 	gchar *tmp_str;
 
     account_number = gsb_gui_navigation_get_current_account ();
@@ -580,7 +637,21 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 	return FALSE;
     }
 
-    /* teste la validité de la date de fin */
+    /* teste si la date de fin inclue toutes les transactions pointées */
+    transactions_max_date = gsb_reconcile_get_pointed_transactions_max_date (account_number);
+    if (g_date_compare (transactions_max_date, date) > 0)
+    {
+		if (!question_yes_no (_("There are pointed transactions that occur later than "
+								"the reconciliation end date.\n"
+							    "If you continue these transactions will be ignored.\n\n"
+								"Do you want to continue?"),
+							  _("Warning: the reconciliation may be incomplete!"),
+							  GTK_RESPONSE_NO))
+
+        return FALSE;
+    }
+
+/* teste la validité de la date de fin */
     reconcile_number = gsb_data_reconcile_get_account_last_number ( account_number );
     if ( reconcile_number )
     {
@@ -616,6 +687,7 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 	gsb_reconcile_list_button_clicked (reconcile_sort_list_button, NULL);
     }
 
+	label_last_statement = grisbi_win_get_label_last_statement ();
     tmp_str = g_strdup_printf ( _("Last statement: %s"), gsb_format_gdate (date));
     gtk_label_set_text ( GTK_LABEL ( label_last_statement ),
 			 tmp_str);
@@ -655,7 +727,7 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 	     &&
 	     ( gsb_data_transaction_get_marked_transaction (transaction_number_tmp) == OPERATION_POINTEE
 	       ||
-	       gsb_data_transaction_get_marked_transaction (transaction_number_tmp) == OPERATION_TELERAPPROCHEE ))
+	       gsb_data_transaction_get_marked_transaction (transaction_number_tmp) == OPERATION_TELEPOINTEE ))
 	{
 	    gsb_data_transaction_set_marked_transaction ( transaction_number_tmp,
 							  OPERATION_RAPPROCHEE );
@@ -688,7 +760,7 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 
     if ( reconcile_save_last_scheduled_convert )
     {
-        gsb_gui_navigation_set_selection ( GSB_SCHEDULER_PAGE, 0, NULL );
+        gsb_gui_navigation_set_selection ( GSB_SCHEDULER_PAGE, 0, 0);
         gsb_scheduler_list_select ( reconcile_save_last_scheduled_convert );
         gsb_scheduler_list_edit_transaction ( reconcile_save_last_scheduled_convert );
         reconcile_save_last_scheduled_convert = 0;
@@ -708,30 +780,8 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
  * */
 void gsb_reconcile_sensitive ( gboolean sensitive )
 {
-    GtkUIManager *ui_manager;
-
-    ui_manager = gsb_menu_get_ui_manager ( );
     gtk_widget_set_sensitive ( gsb_gui_navigation_get_tree_view ( ), sensitive );
-    gsb_gui_sensitive_headings (sensitive);
-    /* add by pbiava 02/11/2009 */
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager,
-                              "/menubar/ViewMenu/ShowReconciled/" ),
-			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager,
-                              "/menubar/ViewMenu/ShowArchived/" ),
-			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
-							  "/menubar/ViewMenu/ShowClosed/" ),
-			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
-							  "/menubar/EditMenu/ConvertToScheduled/" ),
-			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
-							  "/menubar/EditMenu/NewAccount/" ),
-			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
-							  "/menubar/EditMenu/RemoveAccount/" ),
-			       sensitive );
+    grisbi_win_headings_sensitive_headings (sensitive);
 }
 
 
@@ -798,7 +848,7 @@ gboolean gsb_reconcile_cancel ( GtkWidget *button,
 gboolean gsb_reconcile_update_amounts ( GtkWidget *entry,
 					    gpointer null )
 {
-    gsb_real amount;
+    GsbReal amount;
     gint account_number;
     gint currency_number;
     const gchar *initial_balance;
@@ -821,12 +871,12 @@ gboolean gsb_reconcile_update_amounts ( GtkWidget *entry,
         if ( valide )
         {
             /* the entry is valid, make it normal */
-            gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, NULL );
+        gtk_widget_set_name (entry, "form_entry");
         }
         else
         {
             /* the entry is not valid, make it red */
-            gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, gsb_color_get_couleur ( "entry_error_color" ) );
+        gtk_widget_set_name (entry, "form_entry_error");
             return FALSE;
         }
     }
