@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -35,7 +35,10 @@
 /*START_INCLUDE*/
 #include "gsb_scheduler.h"
 #include "accueil.h"
+#include "bet_finance_ui.h"
+#include "grisbi_win.h"
 #include "gsb_currency.h"
+#include "gsb_data_account.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_payment.h"
 #include "gsb_data_scheduled.h"
@@ -44,10 +47,10 @@
 #include "gsb_file.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_transactions_list.h"
-#include "main.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "utils_dates.h"
+#include "utils_real.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -63,9 +66,6 @@ extern GSList *scheduled_transactions_taken;
 extern GSList *scheduled_transactions_to_take;
 /*END_EXTERN*/
 
-/** number of days before the scheduled to execute it */
-gint nb_days_before_scheduled;
-
 /**
  * set the next date in the scheduled transaction
  * if it's above the limit date, that transaction is deleted
@@ -82,6 +82,7 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 
     g_return_val_if_fail ( g_date_valid (gsb_data_scheduled_get_date (scheduled_number)), TRUE );
 
+devel_debug (NULL);
     /* increase the date of the scheduled_transaction */
     new_date = gsb_scheduler_get_next_date ( scheduled_number,
 					     gsb_data_scheduled_get_date (scheduled_number));
@@ -95,6 +96,17 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 	if ( gsb_data_scheduled_get_split_of_scheduled ( scheduled_number ))
 	{
 	    GSList *children_numbers_list;
+		gint transfer_account;
+		gint init_sch_with_loan;
+		GsbReal amount;
+
+		transfer_account = gsb_data_scheduled_get_account_number_transfer (scheduled_number+1);
+		init_sch_with_loan = gsb_data_account_get_bet_init_sch_with_loan (transfer_account);
+		if (init_sch_with_loan)
+		{
+			amount = bet_finance_get_loan_amount_at_date (scheduled_number, transfer_account, new_date, FALSE);
+			gsb_data_scheduled_set_amount (scheduled_number, amount);
+		}
 
 	    /* if there is some children, set the new date too */
 	    children_numbers_list = gsb_data_scheduled_get_children ( scheduled_number, TRUE );
@@ -105,8 +117,13 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 
 		child_number = GPOINTER_TO_INT ( children_numbers_list -> data );
 
-		gsb_data_scheduled_set_date ( child_number,
-					      new_date );
+printf ("set new date and amount = %s\n", gsb_format_gdate(new_date));
+			gsb_data_scheduled_set_date (child_number, new_date);
+			if (init_sch_with_loan)
+			{
+				amount = bet_finance_get_loan_amount_at_date (child_number, transfer_account, new_date, FALSE);
+				gsb_data_scheduled_set_amount (child_number, amount);
+			}
 
 		children_numbers_list = children_numbers_list -> next;
 	    }
@@ -143,7 +160,9 @@ gboolean gsb_scheduler_increase_scheduled ( gint scheduled_number )
 GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 				     const GDate *date )
 {
+	GDate *tmp_date;
     GDate *return_date;
+	gint fixed_date;
 
     if ( !scheduled_number
 	 ||
@@ -154,75 +173,126 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 	 !g_date_valid (date))
 	return NULL;
 
-    /* we don't change the initial date */
+	/* we don't change the initial date */
     return_date = gsb_date_copy (date);
 
+	/* initialise les données pour fixed date */
+	fixed_date = gsb_data_scheduled_get_fixed_date (scheduled_number);
+
     switch (gsb_data_scheduled_get_frequency (scheduled_number))
     {
-	case SCHEDULER_PERIODICITY_ONCE_VIEW:
-	    return NULL;
-	    break;
+		case SCHEDULER_PERIODICITY_ONCE_VIEW:
+			return NULL;
+			break;
 
-	case SCHEDULER_PERIODICITY_WEEK_VIEW:
-	    g_date_add_days ( return_date, 7 );
-	    /* FIXME : there were a bug in gtk and we had to add 0 month to have the good date,
-	     * it seems fixed but we should wait the stable debian is upgraded to
-	     * remove that [26/10/2008] */
-	    g_date_add_months ( return_date, 0 );
-	    break;
+		case SCHEDULER_PERIODICITY_WEEK_VIEW:
+			g_date_add_days ( return_date, 7 );
+			/* FIXME : there were a bug in gtk and we had to add 0 month to have the good date,
+			 * it seems fixed but we should wait the stable debian is upgraded to
+			 * remove that [26/10/2008] */
+			g_date_add_months ( return_date, 0 );
+			break;
 
-	case SCHEDULER_PERIODICITY_MONTH_VIEW:
-	    g_date_add_months ( return_date, 1 );
-	    break;
+		case SCHEDULER_PERIODICITY_MONTH_VIEW:
+			g_date_add_months ( return_date, 1 );
+			/* set the correct date if necessary */
+			if (fixed_date)
+			{
+				tmp_date = gsb_date_copy (return_date);
+				g_date_set_day (return_date, fixed_date);
+				if (!g_date_valid (return_date))
+				{
+					g_date_free (return_date);
+					return_date = gsb_date_get_last_day_of_month (tmp_date);
+				}
+				g_date_free (tmp_date);
+			}
+			break;
 
-	case SCHEDULER_PERIODICITY_TWO_MONTHS_VIEW:
-	    g_date_add_months ( return_date, 2 );
-	    break;
+		case SCHEDULER_PERIODICITY_TWO_MONTHS_VIEW:
+			g_date_add_months ( return_date, 2 );
+			/* set the correct date if necessary */
+			if (fixed_date)
+			{
+				tmp_date = gsb_date_copy (return_date);
+				g_date_set_day (return_date, fixed_date);
+				if (!g_date_valid (return_date))
+				{
+					g_date_free (return_date);
+					return_date = gsb_date_get_last_day_of_month (tmp_date);
+				}
+				g_date_free (tmp_date);
+			}
+			break;
 
-	case SCHEDULER_PERIODICITY_TRIMESTER_VIEW:
-	    g_date_add_months ( return_date, 3 );
-	    break;
+		case SCHEDULER_PERIODICITY_TRIMESTER_VIEW:
+			g_date_add_months ( return_date, 3 );
+			/* set the correct date if necessary */
+			if (fixed_date)
+			{
+				tmp_date = gsb_date_copy (return_date);
+				g_date_set_day (return_date, fixed_date);
+				if (!g_date_valid (return_date))
+				{
+					g_date_free (return_date);
+					return_date = gsb_date_get_last_day_of_month (tmp_date);
+				}
+				g_date_free (tmp_date);
+			}
+			break;
 
-	case SCHEDULER_PERIODICITY_YEAR_VIEW:
-	    g_date_add_years ( return_date, 1 );
-	    break;
+		case SCHEDULER_PERIODICITY_YEAR_VIEW:
+			g_date_add_years ( return_date, 1 );
+			break;
 
-	case SCHEDULER_PERIODICITY_CUSTOM_VIEW:
-	    if ( gsb_data_scheduled_get_user_entry (scheduled_number) <= 0 )
-	    {
-		g_date_free (return_date);
-		return NULL;
-	    }
+		case SCHEDULER_PERIODICITY_CUSTOM_VIEW:
+			if ( gsb_data_scheduled_get_user_entry (scheduled_number) <= 0 )
+			{
+				g_date_free (return_date);
+				return NULL;
+			}
 
-	    switch (gsb_data_scheduled_get_user_interval (scheduled_number))
-	    {
-		case PERIODICITY_DAYS:
-		    g_date_add_days ( return_date,
-				      gsb_data_scheduled_get_user_entry (scheduled_number));
-		    /* FIXME : there were a bug in gtk and we had to add 0 month to have the good date,
-		     * it seems fixed but we should wait the stable debian is upgraded to
-		     * remove that [26/10/2008] */
-		    g_date_add_months ( return_date, 0 );
-		    break;
+			switch (gsb_data_scheduled_get_user_interval (scheduled_number))
+			{
+				case PERIODICITY_DAYS:
+					g_date_add_days ( return_date,
+							  gsb_data_scheduled_get_user_entry (scheduled_number));
+					/* FIXME : there were a bug in gtk and we had to add 0 month to have the good date,
+					 * it seems fixed but we should wait the stable debian is upgraded to
+					 * remove that [26/10/2008] */
+					g_date_add_months ( return_date, 0 );
+					break;
 
-		case PERIODICITY_WEEKS:
-		    g_date_add_days ( return_date,
-				      gsb_data_scheduled_get_user_entry (scheduled_number) * 7 );
-		    g_date_add_months ( return_date, 0 );
-		    break;
+				case PERIODICITY_WEEKS:
+					g_date_add_days ( return_date,
+							  gsb_data_scheduled_get_user_entry (scheduled_number) * 7 );
+					g_date_add_months ( return_date, 0 );
+					break;
 
-		case PERIODICITY_MONTHS:
-		    g_date_add_months ( return_date,
-					gsb_data_scheduled_get_user_entry (scheduled_number));
-		    break;
+				case PERIODICITY_MONTHS:
+					g_date_add_months ( return_date,
+							gsb_data_scheduled_get_user_entry (scheduled_number));
+			/* set the correct date if necessary */
+			if (fixed_date)
+			{
+				tmp_date = gsb_date_copy (return_date);
+				g_date_set_day (return_date, fixed_date);
+				if (!g_date_valid (return_date))
+				{
+					g_date_free (return_date);
+					return_date = gsb_date_get_last_day_of_month (tmp_date);
+				}
+				g_date_free (tmp_date);
+			}
+					break;
 
-		case PERIODICITY_YEARS:
-		    g_date_add_years ( return_date,
-				       gsb_data_scheduled_get_user_entry (scheduled_number));
-		    g_date_add_months ( return_date, 0 );
-		    break;
-	    }
-	    break;
+				case PERIODICITY_YEARS:
+					g_date_add_years ( return_date,
+							   gsb_data_scheduled_get_user_entry (scheduled_number));
+					g_date_add_months ( return_date, 0 );
+					break;
+			}
+			break;
     }
 
     if ( gsb_data_scheduled_get_limit_date (scheduled_number)
@@ -252,21 +322,59 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
 gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint scheduled_number,
 								   gint transaction_mother )
 {
-    gint transaction_number, payment_number;
+	GDate *date;
     gint account_number;
+    gint payment_number;
+	gint transfer_account;
+    gint transaction_number;
 
+	devel_debug_int (scheduled_number);
     account_number = gsb_data_scheduled_get_account_number (scheduled_number);
 
+	transfer_account = gsb_data_scheduled_get_account_number_transfer (scheduled_number+1);
     transaction_number = gsb_data_transaction_new_transaction (account_number);
 
-    /* begin to fill the new transaction */
-    gsb_data_transaction_set_date ( transaction_number,
-				    gsb_date_copy (gsb_data_scheduled_get_date (scheduled_number)));
-    gsb_data_transaction_set_party_number ( transaction_number,
+	/* initialise les données pour fixed date */
+	date = gsb_data_scheduled_get_date (scheduled_number);
+
+	/* begin to fill the new transaction */
+    gsb_data_transaction_set_date (transaction_number, date);
+
+	gsb_data_transaction_set_party_number ( transaction_number,
 					    gsb_data_scheduled_get_party_number (scheduled_number));
-    gsb_data_transaction_set_amount ( transaction_number,
-				      gsb_data_scheduled_get_amount (scheduled_number));
-    gsb_data_transaction_set_currency_number ( transaction_number,
+	if (gsb_data_scheduled_get_split_of_scheduled (scheduled_number)
+		&& gsb_data_account_get_bet_init_sch_with_loan (transfer_account))
+	{
+		GsbReal amount;
+
+		amount = bet_finance_get_loan_amount_at_date (scheduled_number, transfer_account, date, TRUE);
+		gsb_data_transaction_set_amount (transaction_number, amount);
+	}
+	else if (transaction_mother && transfer_account > 0)
+	{
+		gint scheduled_mother;
+
+		if (bet_data_loan_get_last_loan_struct_by_account (transfer_account))
+		{
+			scheduled_mother = gsb_data_scheduled_get_mother_scheduled_number (scheduled_number);
+			if (scheduled_mother == scheduled_number -1
+				|| scheduled_mother == scheduled_number -2
+				|| scheduled_mother == scheduled_number -3)
+			{
+				GsbReal amount;
+
+				amount = bet_finance_get_loan_amount_at_date (scheduled_number, transfer_account, date, FALSE);
+				gsb_data_transaction_set_amount (transaction_number, amount);
+			}
+		}
+		else
+			gsb_data_transaction_set_amount ( transaction_number, gsb_data_scheduled_get_amount (scheduled_number));
+
+	}
+	else
+		gsb_data_transaction_set_amount ( transaction_number, gsb_data_scheduled_get_amount (scheduled_number));
+
+	gsb_data_transaction_set_currency_number ( transaction_number,
 					       gsb_data_scheduled_get_currency_number (scheduled_number));
     gsb_data_transaction_set_account_number ( transaction_number,
 					      account_number );
@@ -355,8 +463,6 @@ gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint schedule
 gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gint transaction_number,
 								       gint scheduled_number )
 {
-	gint contra_account_number;
-
     /* if category is set, it's a normal category */
 
     if ( gsb_data_scheduled_get_category_number (scheduled_number))
@@ -381,27 +487,32 @@ gboolean gsb_scheduler_get_category_for_transaction_from_transaction ( gint tran
     }
     else
     {
-	/* it's not a split of transaction and not a normal category so it's a transfer
-	 * except if the target account is -1 then it's a
-	 * transaction with no category */
+		gint contra_account_number;
 
-	contra_account_number = gsb_data_scheduled_get_account_number_transfer (scheduled_number);
-    if (contra_account_number == 0)
-    {
-      if (run.account_number_is_0 == FALSE)
-        return FALSE;
-    }
+		/* it's not a split of transaction and not a normal category so it's a transfer
+		 * except if the target account is -1 then it's a
+		 * transaction with no category */
 
-    if (contra_account_number != -1)
-    {
-	    gint contra_transaction_number;
+		contra_account_number = gsb_data_scheduled_get_account_number_transfer (scheduled_number);
+		if (contra_account_number == 0)
+		{
+			GrisbiWinRun *w_run;
 
-	    contra_transaction_number = gsb_form_transaction_validate_transfer ( transaction_number,
-										 TRUE,
-										 gsb_data_scheduled_get_account_number_transfer (scheduled_number));
-	    gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
-								gsb_data_scheduled_get_contra_method_of_payment_number (scheduled_number));
-	}
+			w_run = grisbi_win_get_w_run ();
+			if (w_run->account_number_is_0 == FALSE)
+				return FALSE;
+		}
+
+		if (contra_account_number != -1)
+		{
+			gint contra_transaction_number;
+
+			contra_transaction_number = gsb_form_transaction_validate_transfer ( transaction_number,
+											 TRUE,
+											 gsb_data_scheduled_get_account_number_transfer (scheduled_number));
+			gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
+									gsb_data_scheduled_get_contra_method_of_payment_number (scheduled_number));
+		}
     }
     return TRUE;
 }
@@ -423,6 +534,7 @@ gboolean gsb_scheduler_execute_children_of_scheduled_transaction ( gint schedule
 {
     GSList *children_numbers_list;
 
+devel_debug (NULL);
     children_numbers_list = gsb_data_scheduled_get_children ( scheduled_number, TRUE );
 
     while ( children_numbers_list )
@@ -433,7 +545,7 @@ gboolean gsb_scheduler_execute_children_of_scheduled_transaction ( gint schedule
     /* pbiava the 03/16/2009 supprime le crash quand on execute la transaction
      * a partir du planificateur risque d'effet de bord */
     if ( child_number > 0 )
-        gsb_scheduler_create_transaction_from_scheduled_transaction ( child_number,
+		gsb_scheduler_create_transaction_from_scheduled_transaction ( child_number,
 								      transaction_number );
 
 	children_numbers_list = children_numbers_list -> next;
@@ -465,25 +577,36 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 
     scheduled_transactions_to_take = NULL;
 
-    /* get the date today + nb_days_before_scheduled */
+    /* get the date today + conf.nb_days_before_scheduled */
 
     /* the date untill we execute the scheduled transactions is :
-     * - either today + nb_days_before_scheduled if warn n days before the scheduled
-     * - either the end of the month in nb_days_before_scheduled days (so current month or next month)
+     * - either today + conf.nb_days_before_scheduled if warn n days before the scheduled
+     * - either the end of the month in conf.nb_days_before_scheduled days (so current month or next month)
+	 *   or the fixed date
      *   */
     date = gdate_today ();
-    g_date_add_days ( date,
-		      nb_days_before_scheduled );
-    /* now date is in nb_days_before_scheduled, if we want the transactions of the month,
+    /* now date is in conf.nb_days_before_scheduled, if we want the transactions of the month,
      * we change date to the end of its month */
-    if ( conf.execute_scheduled_of_month)
+    if (conf.execute_scheduled_of_month)
     {
-	gint last_day;
+		gint last_day;
 
-	last_day = g_date_get_days_in_month ( g_date_get_month (date),
-					      g_date_get_year (date));
-	g_date_set_day (date, last_day);
+		last_day = g_date_get_days_in_month (g_date_get_month (date),
+											 g_date_get_year (date));
+		if (conf.scheduler_set_fixed_day
+			&&
+			g_date_get_day (date) >= conf.scheduler_fixed_day )
+
+		{
+			g_date_add_months (date, 1);
+		}
+
+		g_date_set_day (date, last_day);
     }
+	else
+	{
+		g_date_add_days ( date, conf.nb_days_before_scheduled );
+	}
 
     /* check all the scheduled transactions,
      * if automatic, it's taken
@@ -492,58 +615,60 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 
     while ( tmp_list )
     {
-	gint scheduled_number;
+		gint scheduled_number;
 
-	scheduled_number = gsb_data_scheduled_get_scheduled_number (tmp_list -> data);
+		scheduled_number = gsb_data_scheduled_get_scheduled_number (tmp_list -> data);
 
-	/* we check that scheduled transaction only if it's not a child of a split */
-	if ( !gsb_data_scheduled_get_mother_scheduled_number (scheduled_number)
-	     &&
-	     gsb_data_scheduled_get_date (scheduled_number)
-	     &&
-	     g_date_compare ( gsb_data_scheduled_get_date (scheduled_number),
-			      date ) <= 0 )
-	{
-	    if ( gsb_data_scheduled_get_automatic_scheduled (scheduled_number))
-	    {
-		/* this is an automatic scheduled, we get it */
-		gint transaction_number;
-
-		/* take automatically the scheduled transaction untill today */
-		transaction_number = gsb_scheduler_create_transaction_from_scheduled_transaction (scheduled_number,
-												  0 );
-		if ( gsb_data_scheduled_get_split_of_scheduled (scheduled_number))
-		    gsb_scheduler_execute_children_of_scheduled_transaction ( scheduled_number,
-									      transaction_number );
-
-		scheduled_transactions_taken = g_slist_append ( scheduled_transactions_taken,
-								GINT_TO_POINTER (transaction_number));
-		automatic_transactions_taken = TRUE;
-
-		/* set the scheduled transaction to the next date,
-		 * if it's not finished, we check them again if it need to be
-		 * executed more than one time (the easiest way is to check
-		 * all again, i don't think it will have thousand of scheduled transactions,
-		 * so no much waste of time...) */
-
-		/* On protège tmp_list si gsb_scheduler_increase_scheduled () return FALSE */
-		tmp_list = tmp_list->next;
-		if (gsb_scheduler_increase_scheduled (scheduled_number))
+		/* we check that scheduled transaction only if it's not a child of a split */
+		if ( !gsb_data_scheduled_get_mother_scheduled_number (scheduled_number)
+			 &&
+			 gsb_data_scheduled_get_date (scheduled_number)
+			 &&
+			 g_date_compare ( gsb_data_scheduled_get_date (scheduled_number),
+					  date ) <= 0 )
 		{
-		    scheduled_transactions_to_take = NULL;
-		    tmp_list = gsb_data_scheduled_get_scheduled_list ();
+			if ( gsb_data_scheduled_get_automatic_scheduled (scheduled_number))
+			{
+				/* this is an automatic scheduled, we get it */
+				gint transaction_number;
+
+				/* take automatically the scheduled transaction untill today */
+				transaction_number = gsb_scheduler_create_transaction_from_scheduled_transaction (scheduled_number,
+														  0 );
+				if ( gsb_data_scheduled_get_split_of_scheduled (scheduled_number))
+					gsb_scheduler_execute_children_of_scheduled_transaction ( scheduled_number,
+												  transaction_number );
+
+				scheduled_transactions_taken = g_slist_append ( scheduled_transactions_taken,
+										GINT_TO_POINTER (transaction_number));
+				automatic_transactions_taken = TRUE;
+
+				/* set the scheduled transaction to the next date,
+				 * if it's not finished, we check them again if it need to be
+				 * executed more than one time (the easiest way is to check
+				 * all again, i don't think it will have thousand of scheduled transactions,
+				 * so no much waste of time...) */
+
+				/* On protège tmp_list si gsb_scheduler_increase_scheduled () return FALSE */
+				tmp_list = tmp_list->next;
+
+				if (gsb_scheduler_increase_scheduled (scheduled_number))
+				{
+					scheduled_transactions_to_take = NULL;
+					tmp_list = gsb_data_scheduled_get_scheduled_list ();
+
+				}
+			}
+			else
+			{
+				/* it's a manual scheduled transaction, we put it in the slist */
+				scheduled_transactions_to_take = g_slist_append ( scheduled_transactions_to_take ,
+										  GINT_TO_POINTER (scheduled_number));
+				tmp_list = tmp_list -> next;
+			}
 		}
-	    }
-	    else
-	    {
-		/* it's a manual scheduled transaction, we put it in the slist */
-		scheduled_transactions_to_take = g_slist_append ( scheduled_transactions_to_take ,
-								  GINT_TO_POINTER (scheduled_number));
-		tmp_list = tmp_list -> next;
-	    }
-	}
-	else
-	    tmp_list = tmp_list -> next;
+		else
+			tmp_list = tmp_list -> next;
     }
 
     if ( automatic_transactions_taken )
@@ -553,7 +678,7 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
     }
 
     if ( scheduled_transactions_to_take )
-	run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+		run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
 
     g_date_free ( date );
 }
