@@ -24,7 +24,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include.h"
@@ -33,10 +33,11 @@
 /*START_INCLUDE*/
 #include "imputation_budgetaire.h"
 #include "dialog.h"
-#include "fenetre_principale.h"
+#include "grisbi_app.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_data_budget.h"
+#include "gsb_data_category.h"
 #include "gsb_data_form.h"
 #include "gsb_data_transaction.h"
 #include "gsb_file.h"
@@ -44,7 +45,6 @@
 #include "gsb_form_widget.h"
 #include "gsb_transactions_list.h"
 #include "gtk_combofix.h"
-#include "main.h"
 #include "meta_budgetary.h"
 #include "metatree.h"
 #include "mouse.h"
@@ -52,7 +52,7 @@
 #include "structures.h"
 #include "utils.h"
 #include "utils_buttons.h"
-#include "utils_file_selection.h"
+#include "utils_files.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -65,9 +65,8 @@ static gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
                         GdkEventButton *ev,
                         gpointer null );
 static void budgetary_line_list_popup_context_menu ( void );
+static GtkWidget *creation_barre_outils_ib ( void );
 static gboolean edit_budgetary_line ( GtkTreeView * view );
-static void exporter_ib ( void );
-static void importer_ib ( void );
 static gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button );
 static void selectionne_sub_budgetary ( GtkTreeModel * model );
 /*END_STATIC*/
@@ -80,7 +79,7 @@ static GtkTreeStore *budgetary_line_tree_model = NULL;
 static gboolean sortie_edit_budgetary_line = FALSE;
 
 /* structure pour la sauvegarde de la position */
-static struct metatree_hold_position *budgetary_hold_position;
+static struct MetatreeHoldPosition *budgetary_hold_position;
 
 /*START_EXTERN*/
 /*END_EXTERN*/
@@ -95,13 +94,14 @@ static struct metatree_hold_position *budgetary_hold_position;
  * */
 void budgetary_lines_init_variables_list ( void )
 {
-    budgetary_line_tree_model = NULL;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = (GrisbiWinEtat *) grisbi_win_get_w_etat ();
+    budgetary_line_tree_model = NULL;
     budgetary_toolbar = NULL;
     budgetary_line_tree = NULL;
-    etat.no_devise_totaux_ib = 1;
-
-    sortie_edit_budgetary_line = FALSE;
+    w_etat->no_devise_totaux_ib = 1;
+	sortie_edit_budgetary_line = FALSE;
 }
 
 
@@ -115,6 +115,7 @@ GtkWidget *budgetary_lines_create_list ( void )
 {
     GtkWidget *scroll_window;
     GtkWidget *vbox;
+    GtkWidget *frame;
     GtkTreeViewColumn *column;
     GtkCellRenderer *cell;
     GtkTreeDragDestIface * dst_iface;
@@ -126,20 +127,22 @@ GtkWidget *budgetary_lines_create_list ( void )
     /* We create the gtktreeview and model early so that they can be referenced. */
     budgetary_line_tree = gtk_tree_view_new();
 
-    /* set the color of selected row */
-    utils_set_tree_view_selection_and_text_color ( budgetary_line_tree );
+	/* set the color of selected row */
+	gtk_widget_set_name (budgetary_line_tree, "tree_view");
 
     budgetary_line_tree_model = gtk_tree_store_new ( META_TREE_NUM_COLUMNS,
 						     META_TREE_COLUMN_TYPES );
 
     /* We create the main vbox */
-    vbox = gtk_vbox_new ( FALSE, 5 );
-    gtk_widget_show ( vbox );
+    vbox = gtk_box_new ( GTK_ORIENTATION_VERTICAL, MARGIN_BOX );
+
+    /* frame pour la barre d'outils */
+    frame = gtk_frame_new ( NULL );
+    gtk_box_pack_start ( GTK_BOX ( vbox ), frame, FALSE, FALSE, 0 );
 
     /* on y ajoute la barre d'outils */
-    budgetary_toolbar = gtk_handle_box_new ( );
-    gtk_widget_show ( budgetary_toolbar );
-    gtk_box_pack_start ( GTK_BOX ( vbox ), budgetary_toolbar, FALSE, FALSE, 0 );
+    budgetary_toolbar = creation_barre_outils_ib ();
+    gtk_container_add ( GTK_CONTAINER ( frame ), budgetary_toolbar );
 
     /* création de l'arbre principal */
     scroll_window = gtk_scrolled_window_new ( NULL, NULL );
@@ -160,7 +163,6 @@ GtkWidget *budgetary_lines_create_list ( void )
                         budgetary_line_get_metatree_interface ( ) );
 
     /* Create container + TreeView */
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (budgetary_line_tree), TRUE);
     gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(budgetary_line_tree),
 					   GDK_BUTTON1_MASK, row_targets, 1,
 					   GDK_ACTION_MOVE | GDK_ACTION_COPY );
@@ -180,7 +182,7 @@ GtkWidget *budgetary_lines_create_list ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Budgetary line"), cell,
 						       "text", META_TREE_TEXT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
@@ -190,18 +192,19 @@ GtkWidget *budgetary_lines_create_list ( void )
     column = gtk_tree_view_column_new_with_attributes (_("Account"), cell,
 						       "text", META_TREE_ACCOUNT_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
 				  GTK_TREE_VIEW_COLUMN ( column ) );
 
     /* Make amount column */
     cell = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Amount"), cell,
+	gtk_cell_renderer_set_padding (GTK_CELL_RENDERER (cell), MARGIN_BOX, 0);
+	column = gtk_tree_view_column_new_with_attributes (_("Amount"), cell,
 						       "text", META_TREE_BALANCE_COLUMN,
 						       "weight", META_TREE_FONT_COLUMN,
 						       "xalign", META_TREE_XALIGN_COLUMN,
-                               "cell-background-gdk", META_TREE_BACKGROUND_COLOR,
+                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
 						       NULL);
     gtk_tree_view_column_set_alignment ( column, 1.0 );
     gtk_tree_view_append_column ( GTK_TREE_VIEW ( budgetary_line_tree ),
@@ -253,7 +256,9 @@ GtkWidget *budgetary_lines_create_list ( void )
 		       budgetary_line_tree_model );
 
     /* création de la structure de sauvegarde de la position */
-    budgetary_hold_position = g_malloc0 ( sizeof ( struct metatree_hold_position ) );
+    budgetary_hold_position = g_malloc0 ( sizeof ( struct MetatreeHoldPosition ) );
+
+    gtk_widget_show_all ( vbox );
 
     return ( vbox );
 }
@@ -352,7 +357,7 @@ void budgetary_lines_fill_list ( void )
             gtk_tree_path_free (ancestor );
         }
         /* on colorise les lignes du tree_view */
-        utils_set_tree_view_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
+        utils_set_tree_store_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( budgetary_line_tree ) );
         gtk_tree_selection_select_path ( selection, budgetary_hold_position -> path );
         gtk_tree_view_scroll_to_cell ( GTK_TREE_VIEW ( budgetary_line_tree ),
@@ -364,11 +369,11 @@ void budgetary_lines_fill_list ( void )
         gchar *title;
 
         /* on colorise les lignes du tree_view */
-        utils_set_tree_view_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
+        utils_set_tree_store_background_color ( budgetary_line_tree, META_TREE_BACKGROUND_COLOR );
 	    title = g_strdup(_("Budgetary lines"));
-        gsb_gui_headings_update_title ( title );
+        grisbi_win_headings_update_title ( title );
         g_free ( title );
-        gsb_gui_headings_update_suffix ( "" );
+        grisbi_win_headings_update_suffix ( "" );
     }
 }
 
@@ -408,9 +413,15 @@ gboolean budgetary_line_drag_data_get ( GtkTreeDragSource * drag_source, GtkTree
 gboolean gsb_budget_update_combofix ( gboolean force )
 {
     if ( gsb_data_form_check_for_value ( TRANSACTION_FORM_BUDGET ) || force )
-        gtk_combofix_set_list ( GTK_COMBOFIX ( gsb_form_widget_get_widget (
-                        TRANSACTION_FORM_BUDGET ) ),
-                        gsb_data_budget_get_name_list ( TRUE, TRUE ) );
+    {
+		GtkWidget *widget;
+    	GSList *tmp_list;
+
+		widget = gsb_form_widget_get_widget (TRANSACTION_FORM_BUDGET);
+		tmp_list = gsb_data_budget_get_name_list (TRUE, TRUE);
+        gtk_combofix_set_list (GTK_COMBOFIX (widget), tmp_list);
+		gsb_data_categorie_free_name_list (tmp_list);
+	}
 
     return FALSE;
 }
@@ -428,10 +439,10 @@ void budgetary_lines_exporter_list ( void )
     gchar *tmp_last_directory;
 
     dialog = gtk_file_chooser_dialog_new ( _("Export the budgetary lines"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-save", GTK_RESPONSE_OK,
 					   NULL);
 
     gtk_file_chooser_set_current_name ( GTK_FILE_CHOOSER ( dialog ),  _("Budgetary-lines.igsb"));
@@ -444,8 +455,8 @@ void budgetary_lines_exporter_list ( void )
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_ib = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
-        tmp_last_directory = file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
+	    nom_ib = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( dialog ));
+        tmp_last_directory = utils_files_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
         gsb_file_update_last_path ( tmp_last_directory );
         g_free ( tmp_last_directory );
 	    gtk_widget_destroy ( GTK_WIDGET ( dialog ));
@@ -480,10 +491,10 @@ void budgetary_lines_importer_list ( void )
     gchar *tmp_last_directory;
 
     dialog = gtk_file_chooser_dialog_new ( _("Import budgetary lines"),
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_FILE_CHOOSER_ACTION_OPEN,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_CANCEL,
+					   "gtk-open", GTK_RESPONSE_OK,
 					   NULL);
 
     gtk_file_chooser_set_current_folder ( GTK_FILE_CHOOSER ( dialog ), gsb_file_get_last_path () );
@@ -513,8 +524,8 @@ void budgetary_lines_importer_list ( void )
 	return;
     }
 
-    budget_name = file_selection_get_filename ( GTK_FILE_CHOOSER ( dialog ));
-    tmp_last_directory = file_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
+    budget_name = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( dialog ));
+    tmp_last_directory = utils_files_selection_get_last_directory ( GTK_FILE_CHOOSER ( dialog ), TRUE );
     gsb_file_update_last_path ( tmp_last_directory );
     g_free ( tmp_last_directory );
     gtk_widget_destroy ( GTK_WIDGET ( dialog ));
@@ -524,13 +535,13 @@ void budgetary_lines_importer_list ( void )
     /* on permet de remplacer/fusionner la liste */
 
     dialog = dialogue_special_no_run ( GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-				       make_hint ( _("Merge imported budgetary lines with existing?"),
-						   ( last_transaction_number ?
-						     _("File already contains budgetary lines.  If you decide to continue, existing budgetary lines will be merged with imported ones.") :
-						     _("File does not contain budgetary lines.  "
-						       "If you decide to continue, existing budgetary lines will be merged with imported ones.  "
-						       "Once performed, there is no undo for this.\n"
-						       "You may also decide to replace existing budgetary lines with imported ones." ) ) ) );
+				       ( last_transaction_number ?
+				         _("File already contains budgetary lines.  If you decide to continue, existing budgetary lines will be merged with imported ones.") :
+				         _("File does not contain budgetary lines.  "
+				           "If you decide to continue, existing budgetary lines will be merged with imported ones.  "
+				           "Once performed, there is no undo for this.\n"
+				           "You may also decide to replace existing budgetary lines with imported ones." ) ),
+				       _("Merge imported budgetary lines with existing?") );
 
     if ( !last_transaction_number)
 	gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
@@ -538,8 +549,8 @@ void budgetary_lines_importer_list ( void )
 				 NULL );
 
     gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
-			     GTK_STOCK_CANCEL, 0,
-			     GTK_STOCK_OK, 1,
+			     "gtk-cancel", 0,
+			     "gtk-ok", 1,
 			     NULL );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
@@ -552,6 +563,7 @@ void budgetary_lines_importer_list ( void )
             if ( !last_transaction_number )
                 gsb_data_budget_init_variables ();
 
+		/* FALLTHRU */
         case 1 :
             if ( g_str_has_suffix ( budget_name, ".cgsb" ) )
                 gsb_file_others_load_budget_from_category ( budget_name );
@@ -574,92 +586,94 @@ void budgetary_lines_importer_list ( void )
  */
 GtkWidget *creation_barre_outils_ib ( void )
 {
-    GtkWidget *hbox, *button;
+    GtkWidget *toolbar;
+    GtkToolItem *item;
 
-    /* Hbox */
-    hbox = gtk_hbox_new ( FALSE, 0 );
+    toolbar = gtk_toolbar_new ();
 
     /* New budgetary line button */
-    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                                _("New\nbudgetary line"), "new-ib.png",
-                                G_CALLBACK ( appui_sur_ajout_imputation ),
-                                budgetary_line_tree_model );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Create a new budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (1) );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-new-ib-24.png", _("New\nbudgetary line"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Create a new budgetary line") );
+    g_object_set_data ( G_OBJECT ( item ), "type", GINT_TO_POINTER (1) );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( appui_sur_ajout_imputation ),
+                        budgetary_line_tree_model );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* New sub budgetary line button */
-    button = gsb_automem_imagefile_button_new ( conf.display_toolbar,
-                                _("New sub\nbudgetary line"),
-                                "new-sub-ib.png",
-                                G_CALLBACK ( appui_sur_ajout_imputation ),
-                                budgetary_line_tree_model );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "selection" );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "sub-division" );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Create a new sub-budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT ( button ), "type", GINT_TO_POINTER (2) );
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-new-sub-ib-24.png", _("New sub\nbudgetary line"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "sub-division" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Create a new sub-budgetary line") );
+    g_object_set_data ( G_OBJECT ( item ), "type", GINT_TO_POINTER (2) );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( appui_sur_ajout_imputation ),
+                        budgetary_line_tree_model );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Import button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                GTK_STOCK_OPEN,
-                                _("Import"),
-                                G_CALLBACK ( budgetary_lines_importer_list ),
-                                NULL );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-import-24.png", _("Import"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ),
                         _("Import a Grisbi budgetary line file (.igsb)"
                         " or create from a list of categories (.cgsb)" ) );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( budgetary_lines_importer_list ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Export button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                GTK_STOCK_SAVE,
-                                _("Export"),
-                                G_CALLBACK ( budgetary_lines_exporter_list ),
-                                NULL );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ),
+    item = utils_buttons_tool_button_new_from_image_label ("gsb-export-24.png", _("Export"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ),
                         _("Export a Grisbi budgetary line file (.igsb)") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( budgetary_lines_exporter_list ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Delete button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                GTK_STOCK_DELETE, _("Delete"),
-                                G_CALLBACK ( supprimer_division ),
-                                budgetary_line_tree );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ), button, "selection" );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Delete selected budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-delete-24.png", _("Delete"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Delete selected budgetary line") );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( supprimer_division ),
+                        budgetary_line_tree );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* Properties button */
-    button = gsb_automem_stock_button_new ( conf.display_toolbar,
-                                GTK_STOCK_EDIT, _("Edit"),
-                                G_CALLBACK ( edit_budgetary_line ),
-                                budgetary_line_tree );
-    metatree_register_widget_as_linked ( GTK_TREE_MODEL(budgetary_line_tree_model), button, "selection" );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Edit selected budgetary line") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-edit-24.png", _("Edit"));
+    metatree_register_widget_as_linked ( GTK_TREE_MODEL ( budgetary_line_tree_model ),
+                        GTK_WIDGET ( item ),
+                        "selection" );
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Edit selected budgetary line") );
+    g_signal_connect_swapped ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( edit_budgetary_line ),
+                        budgetary_line_tree );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     /* View button */
-    button = gsb_automem_stock_button_menu_new ( conf.display_toolbar,
-                                GTK_STOCK_SELECT_COLOR,
-                                _("View"),
-                                G_CALLBACK(popup_budgetary_line_view_mode_menu),
-                                NULL );
-
-    gtk_widget_set_tooltip_text ( GTK_WIDGET ( button ), _("Change display mode") );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, TRUE, 0 );
-
-    gtk_widget_show_all ( hbox );
+    item = utils_buttons_tool_button_new_from_image_label ("gtk-select-color-24.png", _("View"));
+    gtk_widget_set_tooltip_text ( GTK_WIDGET ( item ), _("Change display mode") );
+    g_signal_connect ( G_OBJECT ( item ),
+                        "clicked",
+                        G_CALLBACK ( popup_budgetary_line_view_mode_menu ),
+                        NULL );
+    gtk_toolbar_insert ( GTK_TOOLBAR ( toolbar ), item, -1 );
 
     metatree_set_linked_widgets_sensitive ( GTK_TREE_MODEL ( budgetary_line_tree_model ), FALSE, "selection" );
 
-    return ( hbox );
+    return toolbar;
 }
 
 
@@ -668,20 +682,9 @@ GtkWidget *creation_barre_outils_ib ( void )
  *
  *
  */
-void budgetary_lines_update_toolbar_list ( void )
+void gsb_gui_budgetary_lines_toolbar_set_style ( gint toolbar_style )
 {
-    GList *list = NULL;
-
-    list = gtk_container_get_children ( GTK_CONTAINER ( budgetary_toolbar ) );
-
-    if ( list )
-    {
-        gtk_container_remove ( GTK_CONTAINER ( budgetary_toolbar ),
-                               GTK_WIDGET ( list -> data ) );
-        g_list_free ( list );
-    }
-
-    gtk_container_add ( GTK_CONTAINER ( budgetary_toolbar ), creation_barre_outils_ib () );
+    gtk_toolbar_set_style ( GTK_TOOLBAR ( budgetary_toolbar ), toolbar_style );
 }
 
 
@@ -700,19 +703,19 @@ gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button )
     menu = gtk_menu_new ();
 
     /* Edit transaction */
-    menu_item = gtk_image_menu_item_new_with_label ( _("Budgetary line view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Budgetary line view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 0 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", budgetary_line_tree );
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
 
-    menu_item = gtk_image_menu_item_new_with_label ( _("Sub-budgetary line view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Sub-budgetary line view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 1 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", budgetary_line_tree );
     gtk_menu_shell_append ( GTK_MENU_SHELL ( menu ), menu_item );
 
-    menu_item = gtk_image_menu_item_new_with_label ( _("Complete view") );
+    menu_item = gtk_menu_item_new_with_label ( _("Complete view") );
     g_signal_connect ( G_OBJECT(menu_item), "activate",
 		       G_CALLBACK(expand_arbre_division), (gpointer) 2 );
     g_object_set_data ( G_OBJECT(menu_item), "tree-view", budgetary_line_tree );
@@ -720,9 +723,12 @@ gboolean popup_budgetary_line_view_mode_menu ( GtkWidget * button )
 
     gtk_widget_show_all ( menu );
 
+#if GTK_CHECK_VERSION (3,22,0)
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
+#else
     gtk_menu_popup ( GTK_MENU(menu), NULL, button, set_popup_position, button, 1,
 		     gtk_get_current_event_time());
-
+#endif
     return FALSE;
 }
 
@@ -736,7 +742,7 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
 {
     GtkWidget * dialog, *paddingbox, *table, *label, *entry, *hbox, *radiogroup;
     GtkTreeSelection * selection;
-    GtkTreeModel * model;
+    GtkTreeModel * model = NULL;
     GtkTreeIter iter;
     gint budget_number = -1, sub_budget_number = -1;
     gchar * title;
@@ -766,32 +772,31 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
 							     _("No budget defined") ));
 
     dialog = gtk_dialog_new_with_buttons ( title ,
-					   GTK_WINDOW ( run.window ),
+					   GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
 					   GTK_DIALOG_MODAL,
-					   GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
-					   GTK_STOCK_APPLY, GTK_RESPONSE_OK,
+					   "gtk-cancel", GTK_RESPONSE_NO,
+					   "gtk-apply", GTK_RESPONSE_OK,
 					   NULL );
 
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( dialog ), FALSE );
 
     /* Ugly dance to avoid side effects on dialog's vbox. */
-    hbox = gtk_hbox_new ( FALSE, 0 );
-    gtk_box_pack_start ( GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, FALSE, FALSE, 0 );
+    hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, 0 );
+    gtk_box_pack_start ( GTK_BOX ( dialog_get_content_area ( dialog ) ), hbox, FALSE, FALSE, 0 );
     paddingbox = new_paddingbox_with_title ( hbox, TRUE, title );
     gtk_container_set_border_width ( GTK_CONTAINER(hbox), 6 );
     gtk_container_set_border_width ( GTK_CONTAINER(paddingbox), 6 );
 
-    table = gtk_table_new ( 0, 2, FALSE );
+    table = gtk_grid_new ();
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 6 );
-    gtk_table_set_col_spacings ( GTK_TABLE(table), 6 );
-    gtk_table_set_row_spacings ( GTK_TABLE(table), 6 );
+    gtk_grid_set_column_spacing (GTK_GRID (table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (table), 6);
 
     /* Name entry */
     label = gtk_label_new ( _("Name"));
-    gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-    gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 0, 1,
-		       GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
+    utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+    gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
     entry = gtk_entry_new ( );
     if ( sub_budget_number > 0 )
@@ -808,22 +813,20 @@ gboolean edit_budgetary_line ( GtkTreeView * view )
     }
 
     gtk_widget_set_size_request ( entry, 400, -1 );
-    gtk_table_attach ( GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+    gtk_grid_attach (GTK_GRID (table), entry, 1, 0, 1, 1);
 
     if ( sub_budget_number <= 0 )
     {
 	/* Description entry */
 	label = gtk_label_new ( _("Type"));
-	gtk_misc_set_alignment ( GTK_MISC ( label ), 0.0, 0.5 );
-	gtk_table_attach ( GTK_TABLE(table), label, 0, 1, 1, 2,
-			   GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0 );
+	utils_labels_set_alignment ( GTK_LABEL ( label ), 0.0, 0.5 );
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	radiogroup = gsb_autofunc_radiobutton_new ( _("Credit"), _("Debit"),
 						    gsb_data_budget_get_type (budget_number),
 						    NULL, NULL,
 						    G_CALLBACK (gsb_data_budget_set_type), budget_number);
-	gtk_table_attach ( GTK_TABLE(table), radiogroup,
-			   1, 2, 1, 2, GTK_EXPAND|GTK_FILL, 0, 0, 0 );
+	gtk_grid_attach (GTK_GRID (table), radiogroup, 1, 1, 1, 1);
     }
 
     gtk_widget_show_all ( dialog );
@@ -1052,10 +1055,10 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
     else if ( ev -> type == GDK_2BUTTON_PRESS )
     {
         GtkTreeSelection *selection;
-        GtkTreeModel *model;
+        GtkTreeModel *model = NULL;
         GtkTreeIter iter;
         GtkTreePath *path = NULL;
-        enum meta_tree_row_type type_division;
+        enum MetaTreeRowType type_division;
 
         type_division = metatree_get_row_type_from_tree_view ( tree_view );
         if ( type_division == META_TREE_TRANSACTION )
@@ -1064,6 +1067,8 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
         selection = gtk_tree_view_get_selection ( GTK_TREE_VIEW ( tree_view ) );
         if ( selection && gtk_tree_selection_get_selected (selection, &model, &iter ) )
             path = gtk_tree_model_get_path  ( model, &iter);
+		else
+			return FALSE;
 
         if ( conf.metatree_action_2button_press == 0 || type_division == META_TREE_DIV )
         {
@@ -1086,7 +1091,6 @@ gboolean budgetary_line_list_button_press ( GtkWidget *tree_view,
         {
             if ( type_division == META_TREE_SUB_DIV || type_division == META_TREE_TRANS_S_S_DIV )
             {
-                    path = gtk_tree_model_get_path  ( model, &iter);
                     gtk_tree_view_collapse_row ( GTK_TREE_VIEW ( tree_view ), path );
 
                     gtk_tree_path_free ( path );
@@ -1114,7 +1118,7 @@ void budgetary_line_list_popup_context_menu ( void )
     GtkWidget *menu;
     GtkWidget *menu_item;
     gchar *title;
-    enum meta_tree_row_type type_division;
+    enum MetaTreeRowType type_division;
 
     type_division = metatree_get_row_type_from_tree_view ( budgetary_line_tree );
 
@@ -1127,10 +1131,7 @@ void budgetary_line_list_popup_context_menu ( void )
     {
         title = g_strdup ( _("Transfers the identical transactions in another sub-budgetary line") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
-                        GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gsb-convert-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( metatree_transfer_identical_transactions ),
@@ -1149,10 +1150,7 @@ void budgetary_line_list_popup_context_menu ( void )
         else
             title = g_strdup ( _("Edit selected sub-budgetary line") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                            gtk_image_new_from_stock ( GTK_STOCK_EDIT,
-                            GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gtk-edit-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                             "activate",
                             G_CALLBACK ( edit_budgetary_line ),
@@ -1174,10 +1172,7 @@ void budgetary_line_list_popup_context_menu ( void )
         else
             title = g_strdup ( _("Transfer all transactions in another sub-budgetary line") );
 
-        menu_item = gtk_image_menu_item_new_with_label ( title );
-        gtk_image_menu_item_set_image ( GTK_IMAGE_MENU_ITEM ( menu_item ),
-                        gtk_image_new_from_stock ( GTK_STOCK_CONVERT,
-                        GTK_ICON_SIZE_MENU ) );
+        menu_item = utils_menu_item_new_from_image_label ("gsb-convert-16.png", title);
         g_signal_connect_swapped ( G_OBJECT ( menu_item ),
                         "activate",
                         G_CALLBACK ( metatree_manage_sub_divisions ),
@@ -1190,7 +1185,11 @@ void budgetary_line_list_popup_context_menu ( void )
     /* Finish all. */
     gtk_widget_show_all ( menu );
 
+#if GTK_CHECK_VERSION (3,22,0)
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
+#else
     gtk_menu_popup ( GTK_MENU ( menu ), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time ( ) );
+#endif
 }
 
 
